/*
 * StatQuantGuiView.java
 */
package nl.uu.chem.bioinformatics.statquant.gui;

import jxl.write.WriteException;
import nl.uu.chem.bioinformatics.statquant.util.qvalue;
import nl.uu.chem.bioinformatics.statquant.fastachecker.FastaChecker;
import nl.uu.chem.bioinformatics.statquant.*;
import com.sun.pdfview.PDFViewer;
import java.awt.Dialog.ModalityType;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Observable;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.uu.chem.bioinformatics.*;
import java.awt.event.MouseEvent;
import org.jdesktop.application.Action;
import org.jdesktop.application.ResourceMap;
import org.jdesktop.application.SingleFrameApplication;
import org.jdesktop.application.FrameView;
import org.jdesktop.application.TaskMonitor;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.MouseListener;
import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Observer;
import java.util.Properties;
import java.util.Vector;
import javax.swing.Timer;
import javax.swing.Icon;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JOptionPane;
import javax.swing.SwingUtilities;
import javax.swing.filechooser.FileFilter;
import javax.swing.table.DefaultTableModel;
import nl.uu.chem.bioinformatics.statquant.events.ProcessPreparingEvent;
import nl.uu.chem.bioinformatics.statquant.events.ProcessingFinishedEvent;
import nl.uu.chem.bioinformatics.statquant.events.ProgressEvent;
import nl.uu.chem.bioinformatics.statquant.util.FastaParser;
import nl.uu.chem.bioinformatics.statquant.model.FastaHeaderRegexes;
import nl.uu.chem.bioinformatics.statquant.model.FastaSequence;
import org.apache.commons.math.MathException;
import org.jfree.chart.ChartFactory;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.ChartFrame;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.data.xy.XYSeries;
import org.jfree.data.xy.XYSeriesCollection;

/**
 * The application's main frame.
 */
public class StatQuantGuiView extends FrameView implements Observer {

    public StatQuantGuiView(SingleFrameApplication app) {
        super(app);
        initComponents();
        // status bar initialization - message timeout, idle icon and busy animation, etc
        ResourceMap resourceMap = getResourceMap();

        int messageTimeout = resourceMap.getInteger("StatusBar.messageTimeout");
        messageTimer = new Timer(messageTimeout, new ActionListener() {

            @Override
            public void actionPerformed(ActionEvent e) {
                statusMessageLabel.setText("");
            }
        });
        messageTimer.setRepeats(false);
        int busyAnimationRate = resourceMap.getInteger("StatusBar.busyAnimationRate");
        for (int i = 0; i < busyIcons.length; i++) {
            busyIcons[i] = resourceMap.getIcon("StatusBar.busyIcons[" + i + "]");
        }
        busyIconTimer = new Timer(busyAnimationRate, new ActionListener() {

            @Override
            public void actionPerformed(ActionEvent e) {
                busyIconIndex = (busyIconIndex + 1) % busyIcons.length;
                statusAnimationLabel.setIcon(busyIcons[busyIconIndex]);
            }
        });
        idleIcon = resourceMap.getIcon("StatusBar.idleIcon");
        statusAnimationLabel.setIcon(idleIcon);
        progressBar.setVisible(false);

        // connecting action tasks to status bar via TaskMonitor
        TaskMonitor taskMonitor = new TaskMonitor(getApplication().getContext());
        taskMonitor.addPropertyChangeListener(new java.beans.PropertyChangeListener() {

            @Override
            public void propertyChange(java.beans.PropertyChangeEvent evt) {
                String propertyName = evt.getPropertyName();
                if ("started".equals(propertyName)) {
                    if (!busyIconTimer.isRunning()) {
                        statusAnimationLabel.setIcon(busyIcons[0]);
                        busyIconIndex = 0;
                        busyIconTimer.start();
                    }
                    progressBar.setVisible(true);
                    progressBar.setIndeterminate(true);
                } else if ("done".equals(propertyName)) {
                    busyIconTimer.stop();
                    statusAnimationLabel.setIcon(idleIcon);
                    progressBar.setVisible(false);
                    progressBar.setValue(0);
                } else if ("message".equals(propertyName)) {
                    String text = (String) (evt.getNewValue());
                    statusMessageLabel.setText((text == null) ? "" : text);
                    messageTimer.restart();
                } else if ("progress".equals(propertyName)) {
                    int value = (Integer) (evt.getNewValue());
                    progressBar.setVisible(true);
                    progressBar.setIndeterminate(false);
                    progressBar.setValue(value);
                }
            }
        });
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        mainPanel = new javax.swing.JPanel();
        jSplitPane1 = new javax.swing.JSplitPane();
        TopTabPane = new javax.swing.JTabbedPane();
        BottomTabPane = new javax.swing.JTabbedPane();
        peptidePanel = new javax.swing.JPanel();
        peptideTableScroller = new javax.swing.JScrollPane();
        peptideTable = new javax.swing.JTable();
        menuBar = new javax.swing.JMenuBar();
        javax.swing.JMenu fileMenu = new javax.swing.JMenu();
        LoadMenu = new javax.swing.JMenuItem();
        LoadGenericMenu = new javax.swing.JMenuItem();
        jSeparator2 = new javax.swing.JSeparator();
        SaveMenuItem = new javax.swing.JMenuItem();
        SaveReportItem = new javax.swing.JMenuItem();
        exportMenu = new javax.swing.JMenu();
        exportExcelTab = new javax.swing.JMenuItem();
        exportExcelTabPeps = new javax.swing.JMenuItem();
        jSeparator5 = new javax.swing.JSeparator();
        closeMenuItem = new javax.swing.JMenuItem();
        jSeparator3 = new javax.swing.JSeparator();
        javax.swing.JMenuItem exitMenuItem = new javax.swing.JMenuItem();
        toolsMenu = new javax.swing.JMenu();
        normalizeActiveMenuItem = new javax.swing.JMenuItem();
        normalizeAgainstFactor = new javax.swing.JMenuItem();
        normalizeMenuItem = new javax.swing.JMenuItem();
        prolineconverisonMenuItem = new javax.swing.JMenuItem();
        fastaPeptidetestMenuItem = new javax.swing.JMenuItem();
        selectUnselectUniqueMenuItem = new javax.swing.JMenuItem();
        selectOutlierDetectionMenuItem = new javax.swing.JMenuItem();
        jSeparator1 = new javax.swing.JSeparator();
        CrossExperimentMenu = new javax.swing.JMenuItem();
        plotMenuItem = new javax.swing.JMenuItem();
        helpMenu = new javax.swing.JMenu();
        jMenuItem1 = new javax.swing.JMenuItem();
        jMenuItem2 = new javax.swing.JMenuItem();
        statusPanel = new javax.swing.JPanel();
        javax.swing.JSeparator statusPanelSeparator = new javax.swing.JSeparator();
        statusMessageLabel = new javax.swing.JLabel();
        statusAnimationLabel = new javax.swing.JLabel();
        progressBar = new javax.swing.JProgressBar();
        loadSettingsFrame = new javax.swing.JFrame();
        jLabel1 = new javax.swing.JLabel();
        loadScrollPane = new javax.swing.JScrollPane();
        loadTable = new javax.swing.JTable();
        loadButton = new javax.swing.JButton();
        jLabel7 = new javax.swing.JLabel();
        jLabel8 = new javax.swing.JLabel();
        jLabel20 = new javax.swing.JLabel();
        expNameField = new javax.swing.JTextField();
        jLabel21 = new javax.swing.JLabel();
        jPanel6 = new javax.swing.JPanel();
        jPanel5 = new javax.swing.JPanel();
        proteinTextField = new javax.swing.JLabel();
        proteinNameInput = new javax.swing.JTextField();
        jLabel6 = new javax.swing.JLabel();
        jLabel2 = new javax.swing.JLabel();
        sequenceField = new javax.swing.JTextField();
        jLabel3 = new javax.swing.JLabel();
        modsField = new javax.swing.JTextField();
        jLabel4 = new javax.swing.JLabel();
        areaAfield = new javax.swing.JTextField();
        jLabel5 = new javax.swing.JLabel();
        areaBfield = new javax.swing.JTextField();
        jLabel14 = new javax.swing.JLabel();
        descriptionInput = new javax.swing.JTextField();
        testButton = new javax.swing.JButton();
        jPanel3 = new javax.swing.JPanel();
        jLabel12 = new javax.swing.JLabel();
        jLabel10 = new javax.swing.JLabel();
        jLabel11 = new javax.swing.JLabel();
        jLabel16 = new javax.swing.JLabel();
        jLabel17 = new javax.swing.JLabel();
        jLabel19 = new javax.swing.JLabel();
        reverseLabel = new javax.swing.JCheckBox();
        addPeptideAreasCHeckBox = new javax.swing.JCheckBox();
        PTMinfoCheckbox = new javax.swing.JCheckBox();
        useXICcheck = new javax.swing.JCheckBox();
        peptideReportCheck = new javax.swing.JCheckBox();
        conversionSettingsDialog = new javax.swing.JDialog();
        jScrollPane1 = new javax.swing.JScrollPane();
        conversionFactor = new javax.swing.JTextArea();
        jLabel9 = new javax.swing.JLabel();
        conversionFactorField = new javax.swing.JTextField();
        startConversionButton = new javax.swing.JButton();
        jButton1 = new javax.swing.JButton();
        correctionDialog = new javax.swing.JDialog();
        jPanel1 = new javax.swing.JPanel();
        correctionFactorField = new javax.swing.JTextField();
        jLabel15 = new javax.swing.JLabel();
        applyCorrectionFactor = new javax.swing.JButton();
        jButton2 = new javax.swing.JButton();
        jScrollPane3 = new javax.swing.JScrollPane();
        jTextPane1 = new javax.swing.JTextPane();
        comparisonDialog = new javax.swing.JDialog();
        comparisonScrollpane = new javax.swing.JScrollPane();
        proteinComparisonTable = new javax.swing.JTable();
        jMenuBar2 = new javax.swing.JMenuBar();
        FileMenu = new javax.swing.JMenu();
        SaveItem = new javax.swing.JMenuItem();
        jSeparator4 = new javax.swing.JSeparator();
        Close = new javax.swing.JMenuItem();
        fastaCompareDialog = new javax.swing.JDialog();
        jPanel4 = new javax.swing.JPanel();
        fastaFileChooser = new javax.swing.JFileChooser();
        regexChooser = new javax.swing.JComboBox();
        jLabel13 = new javax.swing.JLabel();
        closeButton = new javax.swing.JButton();
        filterButton = new javax.swing.JButton();
        fastaScroller = new javax.swing.JScrollPane();
        fastapreview = new javax.swing.JTextPane();
        jLabel18 = new javax.swing.JLabel();
        regexLabel = new javax.swing.JLabel();
        progressDialog = new javax.swing.JDialog();
        eventProgressBar = new javax.swing.JProgressBar();

        jSplitPane1.setDividerLocation(400);
        jSplitPane1.setDividerSize(10);
        jSplitPane1.setOrientation(javax.swing.JSplitPane.VERTICAL_SPLIT);
        jSplitPane1.setContinuousLayout(true);
        jSplitPane1.setLeftComponent(TopTabPane);

        peptideTable.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {

            },
            new String [] {

            }
        ));
        peptideTableScroller.setViewportView(peptideTable);

        org.jdesktop.layout.GroupLayout peptidePanelLayout = new org.jdesktop.layout.GroupLayout(peptidePanel);
        peptidePanel.setLayout(peptidePanelLayout);
        peptidePanelLayout.setHorizontalGroup(
            peptidePanelLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(peptideTableScroller, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 737, Short.MAX_VALUE)
        );
        peptidePanelLayout.setVerticalGroup(
            peptidePanelLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(org.jdesktop.layout.GroupLayout.TRAILING, peptideTableScroller, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 107, Short.MAX_VALUE)
        );

        BottomTabPane.addTab("none", peptidePanel);

        jSplitPane1.setRightComponent(BottomTabPane);

        org.jdesktop.layout.GroupLayout mainPanelLayout = new org.jdesktop.layout.GroupLayout(mainPanel);
        mainPanel.setLayout(mainPanelLayout);
        mainPanelLayout.setHorizontalGroup(
            mainPanelLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(mainPanelLayout.createSequentialGroup()
                .addContainerGap()
                .add(jSplitPane1, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 744, Short.MAX_VALUE)
                .addContainerGap())
        );
        mainPanelLayout.setVerticalGroup(
            mainPanelLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(mainPanelLayout.createSequentialGroup()
                .addContainerGap()
                .add(jSplitPane1, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 546, Short.MAX_VALUE)
                .addContainerGap())
        );

        fileMenu.setText("File"); // NOI18N

        LoadMenu.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_O, java.awt.event.InputEvent.CTRL_MASK));
        LoadMenu.setText("Open MSQuant file"); // NOI18N
        LoadMenu.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                LoadMenuActionPerformed(evt);
            }
        });
        fileMenu.add(LoadMenu);

        LoadGenericMenu.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_G, java.awt.event.InputEvent.CTRL_MASK));
        org.jdesktop.application.ResourceMap resourceMap = org.jdesktop.application.Application.getInstance(nl.uu.chem.bioinformatics.statquant.gui.StatQuantGui.class).getContext().getResourceMap(StatQuantGuiView.class);
        LoadGenericMenu.setText(resourceMap.getString("LoadGenericMenu.text")); // NOI18N
        LoadGenericMenu.setToolTipText(resourceMap.getString("LoadGenericMenu.toolTipText")); // NOI18N
        LoadGenericMenu.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                LoadGenericMenuMouseReleased(evt);
            }
        });
        fileMenu.add(LoadGenericMenu);
        fileMenu.add(jSeparator2);

        SaveMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_S, java.awt.event.InputEvent.CTRL_MASK));
        SaveMenuItem.setText("Save Active Tab"); // NOI18N
        SaveMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                SaveTabActionPerformed(evt);
            }
        });
        fileMenu.add(SaveMenuItem);

        SaveReportItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_S, java.awt.event.InputEvent.ALT_MASK | java.awt.event.InputEvent.CTRL_MASK));
        SaveReportItem.setText("Save Report (Active Tab)"); // NOI18N
        SaveReportItem.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                SaveReportItemMouseReleased(evt);
            }
        });
        fileMenu.add(SaveReportItem);

        exportMenu.setText(resourceMap.getString("exportMenu.text")); // NOI18N

        javax.swing.ActionMap actionMap = org.jdesktop.application.Application.getInstance(nl.uu.chem.bioinformatics.statquant.gui.StatQuantGui.class).getContext().getActionMap(StatQuantGuiView.class, this);
        exportExcelTab.setAction(actionMap.get("saveExcelProtList")); // NOI18N
        exportExcelTab.setText(resourceMap.getString("exportExcelTab.text")); // NOI18N
        exportMenu.add(exportExcelTab);

        exportExcelTabPeps.setAction(actionMap.get("saveExcelReport")); // NOI18N
        exportExcelTabPeps.setText(resourceMap.getString("exportExcelTabPeps.text")); // NOI18N
        exportMenu.add(exportExcelTabPeps);

        fileMenu.add(exportMenu);
        fileMenu.add(jSeparator5);

        closeMenuItem.setText(resourceMap.getString("closeMenuItem.text")); // NOI18N
        closeMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                closeMenuItemActionPerformed(evt);
            }
        });
        fileMenu.add(closeMenuItem);
        fileMenu.add(jSeparator3);

        exitMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_Q, java.awt.event.InputEvent.CTRL_MASK));
        exitMenuItem.setText("Exit"); // NOI18N
        exitMenuItem.setAction(org.jdesktop.application.Application.getInstance(StatQuantGui.class).getContext().getActionMap(StatQuantGuiView.class, this).get("quit"));
        exitMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                exitMenuItemActionPerformed(evt);
            }
        });
        fileMenu.add(exitMenuItem);

        menuBar.add(fileMenu);

        toolsMenu.setText("Process"); // NOI18N
        toolsMenu.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                toolsMenuActionPerformed(evt);
            }
        });

        normalizeActiveMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_N, java.awt.event.InputEvent.CTRL_MASK));
        normalizeActiveMenuItem.setText("Normalize active tab"); // NOI18N
        normalizeActiveMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                normalizeActiveMenuItemMouseReleased(evt);
            }
        });
        toolsMenu.add(normalizeActiveMenuItem);

        normalizeAgainstFactor.setText("Normalize against factor"); // NOI18N
        normalizeAgainstFactor.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                normalizeAgainstFactorMouseReleased(evt);
            }
        });
        toolsMenu.add(normalizeAgainstFactor);

        normalizeMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_N, java.awt.event.InputEvent.SHIFT_MASK | java.awt.event.InputEvent.CTRL_MASK));
        normalizeMenuItem.setText("Normalize all experiments"); // NOI18N
        normalizeMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                normalizeMenuItemMouseReleased(evt);
            }
        });
        toolsMenu.add(normalizeMenuItem);

        prolineconverisonMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_M, java.awt.event.InputEvent.CTRL_MASK));
        prolineconverisonMenuItem.setText("Proline conversion"); // NOI18N
        prolineconverisonMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                prolineconverisonMenuItemMouseReleased(evt);
            }
        });
        toolsMenu.add(prolineconverisonMenuItem);

        fastaPeptidetestMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_U, java.awt.event.InputEvent.CTRL_MASK));
        fastaPeptidetestMenuItem.setText("Check peptide uniqueness"); // NOI18N
        fastaPeptidetestMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                fastaPeptidetestMenuItemActionPerformed(evt);
            }
        });
        toolsMenu.add(fastaPeptidetestMenuItem);

        selectUnselectUniqueMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_U, java.awt.event.InputEvent.SHIFT_MASK | java.awt.event.InputEvent.CTRL_MASK));
        selectUnselectUniqueMenuItem.setText(resourceMap.getString("selectUnselectUniqueMenuItem.text")); // NOI18N
        selectUnselectUniqueMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                selectUnselectUniqueMenuItemMouseReleased(evt);
            }
        });
        toolsMenu.add(selectUnselectUniqueMenuItem);

        selectOutlierDetectionMenuItem.setText(resourceMap.getString("selectOutlierDetectionMenuItem.text")); // NOI18N
        selectOutlierDetectionMenuItem.setToolTipText(resourceMap.getString("selectOutlierDetectionMenuItem.toolTipText")); // NOI18N
        selectOutlierDetectionMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                selectOutlierDetectionMenuItemMouseReleased(evt);
            }
        });
        toolsMenu.add(selectOutlierDetectionMenuItem);
        toolsMenu.add(jSeparator1);

        CrossExperimentMenu.setText("Compare experiments"); // NOI18N
        CrossExperimentMenu.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                CrossExperimentMenuMouseReleased(evt);
            }
        });
        toolsMenu.add(CrossExperimentMenu);

        plotMenuItem.setText("Plot experiment"); // NOI18N
        plotMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                plotMenuItemMouseReleased(evt);
            }
        });
        toolsMenu.add(plotMenuItem);

        menuBar.add(toolsMenu);

        helpMenu.setAction(actionMap.get("helpQuickStart")); // NOI18N
        helpMenu.setText(resourceMap.getString("helpMenu.text")); // NOI18N

        jMenuItem1.setAction(actionMap.get("helpQuickStart")); // NOI18N
        jMenuItem1.setText(resourceMap.getString("jMenuItem1.text")); // NOI18N
        helpMenu.add(jMenuItem1);

        jMenuItem2.setText(resourceMap.getString("jMenuItem2.text")); // NOI18N
        jMenuItem2.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                AboutActionPerformed(evt);
            }
        });
        helpMenu.add(jMenuItem2);

        menuBar.add(helpMenu);

        statusAnimationLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);

        org.jdesktop.layout.GroupLayout statusPanelLayout = new org.jdesktop.layout.GroupLayout(statusPanel);
        statusPanel.setLayout(statusPanelLayout);
        statusPanelLayout.setHorizontalGroup(
            statusPanelLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(statusPanelSeparator, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 764, Short.MAX_VALUE)
            .add(statusPanelLayout.createSequentialGroup()
                .addContainerGap()
                .add(statusMessageLabel)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED, 594, Short.MAX_VALUE)
                .add(progressBar, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(statusAnimationLabel)
                .addContainerGap())
        );
        statusPanelLayout.setVerticalGroup(
            statusPanelLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(statusPanelLayout.createSequentialGroup()
                .add(statusPanelSeparator, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 2, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED, 8, Short.MAX_VALUE)
                .add(statusPanelLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(statusMessageLabel)
                    .add(statusAnimationLabel)
                    .add(progressBar, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .add(3, 3, 3))
        );

        loadSettingsFrame.setMinimumSize(new java.awt.Dimension(585, 512));

        jLabel1.setText("1) Does the table show the right columns?"); // NOI18N

        loadTable.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {

            },
            new String [] {

            }
        ));
        loadScrollPane.setViewportView(loadTable);

        loadButton.setText("Load"); // NOI18N
        loadButton.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                loadButtonMouseReleased(evt);
            }
        });

        jLabel7.setText("2) If not find the right column numbers (start from 0 not 1) and enter them below. Press test to evaluate the result."); // NOI18N

        jLabel8.setText("4) Press load to read the MSQ file(s)"); // NOI18N

        jLabel20.setText(resourceMap.getString("jLabel20.text")); // NOI18N

        expNameField.setText(resourceMap.getString("expNameField.text")); // NOI18N
        expNameField.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                expNameFieldActionPerformed(evt);
            }
        });

        jLabel21.setText(resourceMap.getString("jLabel21.text")); // NOI18N

        jPanel6.setLayout(new java.awt.GridLayout(1, 2));

        proteinTextField.setText("Protein ID* (pep list only!)"); // NOI18N

        proteinNameInput.setText(resourceMap.getString("proteinNameInput.text")); // NOI18N
        proteinNameInput.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                proteinNameInputActionPerformed(evt);
            }
        });

        jLabel6.setText("Column Number"); // NOI18N

        jLabel2.setText("Peptide sequence "); // NOI18N

        jLabel3.setText("Peptide Mods"); // NOI18N

        jLabel4.setText("Area A (signal A)"); // NOI18N

        jLabel5.setText("Area B (Signal B)"); // NOI18N

        areaBfield.setText(resourceMap.getString("areaBfield.text")); // NOI18N

        jLabel14.setText("Description"); // NOI18N

        descriptionInput.setText(resourceMap.getString("descriptionInput.text")); // NOI18N

        testButton.setText(resourceMap.getString("testButton.text")); // NOI18N
        testButton.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                testButtonMouseReleased(evt);
            }
        });
        testButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                testButtonActionPerformed(evt);
            }
        });

        org.jdesktop.layout.GroupLayout jPanel5Layout = new org.jdesktop.layout.GroupLayout(jPanel5);
        jPanel5.setLayout(jPanel5Layout);
        jPanel5Layout.setHorizontalGroup(
            jPanel5Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanel5Layout.createSequentialGroup()
                .addContainerGap()
                .add(jPanel5Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(jLabel2)
                    .add(jLabel4)
                    .add(jLabel5)
                    .add(proteinTextField)
                    .add(jLabel14)
                    .add(jLabel3))
                .add(21, 21, 21)
                .add(jPanel5Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING, false)
                    .add(modsField)
                    .add(org.jdesktop.layout.GroupLayout.TRAILING, testButton, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .add(org.jdesktop.layout.GroupLayout.TRAILING, proteinNameInput)
                    .add(areaBfield)
                    .add(areaAfield)
                    .add(jLabel6, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .add(descriptionInput)
                    .add(sequenceField))
                .addContainerGap(50, Short.MAX_VALUE))
        );
        jPanel5Layout.setVerticalGroup(
            jPanel5Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanel5Layout.createSequentialGroup()
                .addContainerGap()
                .add(jLabel6)
                .add(18, 18, 18)
                .add(jPanel5Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(proteinTextField)
                    .add(proteinNameInput, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .add(9, 9, 9)
                .add(jPanel5Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(jLabel2)
                    .add(sequenceField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .add(9, 9, 9)
                .add(jPanel5Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(modsField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(jLabel3))
                .add(6, 6, 6)
                .add(jPanel5Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(jLabel4)
                    .add(areaAfield, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanel5Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(jLabel5)
                    .add(areaBfield, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanel5Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(descriptionInput, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(jLabel14))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED, 14, Short.MAX_VALUE)
                .add(testButton)
                .addContainerGap())
        );

        jPanel6.add(jPanel5);

        jLabel12.setText("LOAD SETTINGS :"); // NOI18N

        jLabel10.setText("Reverse Label"); // NOI18N

        jLabel11.setText("Add peptide areas"); // NOI18N

        jLabel16.setText("use PTM info"); // NOI18N

        jLabel17.setText("create Peptide report"); // NOI18N

        jLabel19.setText(resourceMap.getString("jLabel19.text")); // NOI18N

        reverseLabel.setText(resourceMap.getString("reverseLabel.text")); // NOI18N
        reverseLabel.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        reverseLabel.setMargin(new java.awt.Insets(0, 0, 0, 0));

        addPeptideAreasCHeckBox.setText(resourceMap.getString("addPeptideAreasCHeckBox.text")); // NOI18N
        addPeptideAreasCHeckBox.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        addPeptideAreasCHeckBox.setMargin(new java.awt.Insets(0, 0, 0, 0));

        PTMinfoCheckbox.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        PTMinfoCheckbox.setMargin(new java.awt.Insets(0, 0, 0, 0));

        useXICcheck.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        useXICcheck.setMargin(new java.awt.Insets(0, 0, 0, 0));

        peptideReportCheck.setBorder(null);

        org.jdesktop.layout.GroupLayout jPanel3Layout = new org.jdesktop.layout.GroupLayout(jPanel3);
        jPanel3.setLayout(jPanel3Layout);
        jPanel3Layout.setHorizontalGroup(
            jPanel3Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanel3Layout.createSequentialGroup()
                .addContainerGap()
                .add(jPanel3Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(jLabel12)
                    .add(jLabel16)
                    .add(jPanel3Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.TRAILING)
                        .add(jPanel3Layout.createSequentialGroup()
                            .add(jPanel3Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                                .add(jLabel10)
                                .add(jLabel11))
                            .add(19, 19, 19)
                            .add(jPanel3Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.TRAILING)
                                .add(addPeptideAreasCHeckBox, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 13, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                                .add(reverseLabel)))
                        .add(jPanel3Layout.createSequentialGroup()
                            .add(jPanel3Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                                .add(jLabel17)
                                .add(jLabel19))
                            .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                            .add(jPanel3Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                                .add(useXICcheck)
                                .add(peptideReportCheck)
                                .add(PTMinfoCheckbox)))))
                .addContainerGap(152, Short.MAX_VALUE))
        );
        jPanel3Layout.setVerticalGroup(
            jPanel3Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanel3Layout.createSequentialGroup()
                .addContainerGap()
                .add(jLabel12)
                .add(18, 18, 18)
                .add(jPanel3Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.TRAILING)
                    .add(jLabel10)
                    .add(reverseLabel))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanel3Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.TRAILING)
                    .add(addPeptideAreasCHeckBox)
                    .add(jLabel11))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanel3Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(jLabel16)
                    .add(PTMinfoCheckbox))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanel3Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(useXICcheck)
                    .add(jLabel19))
                .add(7, 7, 7)
                .add(jPanel3Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(peptideReportCheck)
                    .add(jLabel17))
                .addContainerGap(109, Short.MAX_VALUE))
        );

        jPanel6.add(jPanel3);

        org.jdesktop.layout.GroupLayout loadSettingsFrameLayout = new org.jdesktop.layout.GroupLayout(loadSettingsFrame.getContentPane());
        loadSettingsFrame.getContentPane().setLayout(loadSettingsFrameLayout);
        loadSettingsFrameLayout.setHorizontalGroup(
            loadSettingsFrameLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(loadSettingsFrameLayout.createSequentialGroup()
                .addContainerGap()
                .add(loadSettingsFrameLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(loadScrollPane, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 565, Short.MAX_VALUE)
                    .add(jPanel6, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 565, Short.MAX_VALUE)
                    .add(jLabel1)
                    .add(jLabel7)
                    .add(loadSettingsFrameLayout.createSequentialGroup()
                        .add(10, 10, 10)
                        .add(loadSettingsFrameLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                            .add(jLabel21, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 555, Short.MAX_VALUE)
                            .add(org.jdesktop.layout.GroupLayout.TRAILING, loadSettingsFrameLayout.createSequentialGroup()
                                .add(jLabel8, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 174, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED, 326, Short.MAX_VALUE)
                                .add(loadButton))
                            .add(loadSettingsFrameLayout.createSequentialGroup()
                                .add(jLabel20)
                                .addPreferredGap(org.jdesktop.layout.LayoutStyle.UNRELATED)
                                .add(expNameField, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 449, Short.MAX_VALUE)))))
                .addContainerGap())
        );
        loadSettingsFrameLayout.setVerticalGroup(
            loadSettingsFrameLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(loadSettingsFrameLayout.createSequentialGroup()
                .addContainerGap()
                .add(jLabel1)
                .add(7, 7, 7)
                .add(loadScrollPane, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 68, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .add(18, 18, 18)
                .add(jLabel7)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanel6, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .add(18, 18, 18)
                .add(loadSettingsFrameLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(jLabel20)
                    .add(expNameField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .add(20, 20, 20)
                .add(loadSettingsFrameLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(jLabel8)
                    .add(loadButton))
                .add(7, 7, 7)
                .add(jLabel21, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 28, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addContainerGap())
        );

        conversionFactor.setColumns(20);
        conversionFactor.setRows(5);
        conversionFactor.setText(resourceMap.getString("conversionFactor.text")); // NOI18N
        jScrollPane1.setViewportView(conversionFactor);

        jLabel9.setText("Conversion factor"); // NOI18N

        conversionFactorField.setText("0.1"); // NOI18N

        startConversionButton.setText("start"); // NOI18N
        startConversionButton.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                startConversionButtonMouseReleased(evt);
            }
        });

        jButton1.setAction(actionMap.get("conversionCancelAction")); // NOI18N
        jButton1.setText(resourceMap.getString("jButton1.text")); // NOI18N

        org.jdesktop.layout.GroupLayout conversionSettingsDialogLayout = new org.jdesktop.layout.GroupLayout(conversionSettingsDialog.getContentPane());
        conversionSettingsDialog.getContentPane().setLayout(conversionSettingsDialogLayout);
        conversionSettingsDialogLayout.setHorizontalGroup(
            conversionSettingsDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(conversionSettingsDialogLayout.createSequentialGroup()
                .addContainerGap()
                .add(conversionSettingsDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(conversionSettingsDialogLayout.createSequentialGroup()
                        .add(jLabel9)
                        .add(18, 18, 18)
                        .add(conversionFactorField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 53, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED, 174, Short.MAX_VALUE)
                        .add(startConversionButton)
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                        .add(jButton1))
                    .add(jScrollPane1, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 455, Short.MAX_VALUE))
                .addContainerGap())
        );
        conversionSettingsDialogLayout.setVerticalGroup(
            conversionSettingsDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(conversionSettingsDialogLayout.createSequentialGroup()
                .addContainerGap()
                .add(jScrollPane1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 211, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .add(18, 18, 18)
                .add(conversionSettingsDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(jLabel9)
                    .add(conversionFactorField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(jButton1)
                    .add(startConversionButton))
                .addContainerGap(org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        correctionFactorField.setText("0.1"); // NOI18N

        jLabel15.setText("Correction factor"); // NOI18N

        applyCorrectionFactor.setText("start"); // NOI18N
        applyCorrectionFactor.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                applyCorrectionFactorMouseReleased(evt);
            }
        });

        jButton2.setAction(actionMap.get("correctionDialogCancelButtonAction")); // NOI18N
        jButton2.setText(resourceMap.getString("jButton2.text")); // NOI18N

        org.jdesktop.layout.GroupLayout jPanel1Layout = new org.jdesktop.layout.GroupLayout(jPanel1);
        jPanel1.setLayout(jPanel1Layout);
        jPanel1Layout.setHorizontalGroup(
            jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanel1Layout.createSequentialGroup()
                .addContainerGap()
                .add(jLabel15)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(correctionFactorField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 71, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED, 227, Short.MAX_VALUE)
                .add(applyCorrectionFactor)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jButton2))
        );
        jPanel1Layout.setVerticalGroup(
            jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanel1Layout.createSequentialGroup()
                .addContainerGap()
                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(correctionFactorField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(jLabel15)
                    .add(jButton2)
                    .add(applyCorrectionFactor))
                .addContainerGap())
        );

        jTextPane1.setText("Please enter the correction factor for this experiment.\nE.q. the correction factor is applied as:\n2Log ratio - factor;  \nSo, if your 2LOG median is for example -0.2  and you would expect 0, than your correction factor is -0.2 \n-0.2 - (- 0.2) = 0;"); // NOI18N
        jScrollPane3.setViewportView(jTextPane1);

        org.jdesktop.layout.GroupLayout correctionDialogLayout = new org.jdesktop.layout.GroupLayout(correctionDialog.getContentPane());
        correctionDialog.getContentPane().setLayout(correctionDialogLayout);
        correctionDialogLayout.setHorizontalGroup(
            correctionDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(org.jdesktop.layout.GroupLayout.TRAILING, correctionDialogLayout.createSequentialGroup()
                .addContainerGap()
                .add(correctionDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.TRAILING)
                    .add(org.jdesktop.layout.GroupLayout.LEADING, jScrollPane3, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 518, Short.MAX_VALUE)
                    .add(org.jdesktop.layout.GroupLayout.LEADING, jPanel1, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addContainerGap())
        );
        correctionDialogLayout.setVerticalGroup(
            correctionDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(correctionDialogLayout.createSequentialGroup()
                .addContainerGap()
                .add(jScrollPane3, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanel1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        proteinComparisonTable.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {
                {}
            },
            new String [] {

            }
        ));
        comparisonScrollpane.setViewportView(proteinComparisonTable);

        FileMenu.setText("File"); // NOI18N
        FileMenu.setMaximumSize(new java.awt.Dimension(29, 29));
        FileMenu.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                FileMenuActionPerformed(evt);
            }
        });

        SaveItem.setText("Save"); // NOI18N
        SaveItem.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                SaveItemMouseReleased(evt);
            }
        });
        SaveItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                SaveItemActionPerformed(evt);
            }
        });
        FileMenu.add(SaveItem);
        FileMenu.add(jSeparator4);

        Close.setText("Close"); // NOI18N
        Close.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                CloseMouseReleased(evt);
            }
        });
        FileMenu.add(Close);

        jMenuBar2.add(FileMenu);

        comparisonDialog.setJMenuBar(jMenuBar2);

        org.jdesktop.layout.GroupLayout comparisonDialogLayout = new org.jdesktop.layout.GroupLayout(comparisonDialog.getContentPane());
        comparisonDialog.getContentPane().setLayout(comparisonDialogLayout);
        comparisonDialogLayout.setHorizontalGroup(
            comparisonDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(comparisonDialogLayout.createSequentialGroup()
                .addContainerGap()
                .add(comparisonScrollpane, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 734, Short.MAX_VALUE)
                .addContainerGap())
        );
        comparisonDialogLayout.setVerticalGroup(
            comparisonDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(org.jdesktop.layout.GroupLayout.TRAILING, comparisonDialogLayout.createSequentialGroup()
                .addContainerGap()
                .add(comparisonScrollpane, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 407, Short.MAX_VALUE)
                .addContainerGap())
        );

        fastaCompareDialog.setTitle("Check peptides in Fasta file for uniqueness"); // NOI18N
        fastaCompareDialog.setMinimumSize(new java.awt.Dimension(800, 650));

        jPanel4.setBorder(javax.swing.BorderFactory.createEtchedBorder());

        fastaFileChooser.setControlButtonsAreShown(false);
        fastaFileChooser.addPropertyChangeListener(new java.beans.PropertyChangeListener() {
            public void propertyChange(java.beans.PropertyChangeEvent evt) {
                fastaFileChooserPropertyChange(evt);
            }
        });

        org.jdesktop.layout.GroupLayout jPanel4Layout = new org.jdesktop.layout.GroupLayout(jPanel4);
        jPanel4.setLayout(jPanel4Layout);
        jPanel4Layout.setHorizontalGroup(
            jPanel4Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(org.jdesktop.layout.GroupLayout.TRAILING, jPanel4Layout.createSequentialGroup()
                .addContainerGap()
                .add(fastaFileChooser, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addContainerGap())
        );
        jPanel4Layout.setVerticalGroup(
            jPanel4Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(org.jdesktop.layout.GroupLayout.TRAILING, jPanel4Layout.createSequentialGroup()
                .addContainerGap()
                .add(fastaFileChooser, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 353, Short.MAX_VALUE)
                .addContainerGap())
        );

        regexChooser.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                regexChooserItemStateChanged(evt);
            }
        });

        jLabel13.setText("Fasta file type"); // NOI18N

        closeButton.setText("close"); // NOI18N
        closeButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                close(evt);
            }
        });

        filterButton.setText("Filter"); // NOI18N
        filterButton.setEnabled(false);
        filterButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                filterButtonActionPerformed(evt);
            }
        });

        fastapreview.setContentType("text/html"); // NOI18N
        fastapreview.setText("\n"); // NOI18N
        fastapreview.setToolTipText("Preview of a sequence using the fasta file type"); // NOI18N
        fastaScroller.setViewportView(fastapreview);

        jLabel18.setText("Test preview"); // NOI18N

        org.jdesktop.layout.GroupLayout fastaCompareDialogLayout = new org.jdesktop.layout.GroupLayout(fastaCompareDialog.getContentPane());
        fastaCompareDialog.getContentPane().setLayout(fastaCompareDialogLayout);
        fastaCompareDialogLayout.setHorizontalGroup(
            fastaCompareDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(fastaCompareDialogLayout.createSequentialGroup()
                .addContainerGap()
                .add(fastaCompareDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(fastaScroller, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 581, Short.MAX_VALUE)
                    .add(jPanel4, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .add(fastaCompareDialogLayout.createSequentialGroup()
                        .add(jLabel13)
                        .add(8, 8, 8)
                        .add(regexChooser, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 161, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED, 223, Short.MAX_VALUE)
                        .add(filterButton)
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                        .add(closeButton))
                    .add(fastaCompareDialogLayout.createSequentialGroup()
                        .add(jLabel18)
                        .add(18, 18, 18)
                        .add(regexLabel)))
                .addContainerGap())
        );
        fastaCompareDialogLayout.setVerticalGroup(
            fastaCompareDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(fastaCompareDialogLayout.createSequentialGroup()
                .addContainerGap()
                .add(jPanel4, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(fastaCompareDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(regexChooser, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(jLabel13)
                    .add(filterButton)
                    .add(closeButton))
                .add(18, 18, 18)
                .add(fastaCompareDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(jLabel18)
                    .add(regexLabel))
                .add(13, 13, 13)
                .add(fastaScroller, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 98, Short.MAX_VALUE)
                .addContainerGap())
        );

        progressDialog.setTitle("Progress"); // NOI18N
        progressDialog.setLocationByPlatform(true);
        progressDialog.setMinimumSize(new java.awt.Dimension(600, 80));
        progressDialog.setResizable(false);

        org.jdesktop.layout.GroupLayout progressDialogLayout = new org.jdesktop.layout.GroupLayout(progressDialog.getContentPane());
        progressDialog.getContentPane().setLayout(progressDialogLayout);
        progressDialogLayout.setHorizontalGroup(
            progressDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(progressDialogLayout.createSequentialGroup()
                .addContainerGap()
                .add(eventProgressBar, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 500, Short.MAX_VALUE)
                .addContainerGap())
        );
        progressDialogLayout.setVerticalGroup(
            progressDialogLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(progressDialogLayout.createSequentialGroup()
                .addContainerGap()
                .add(eventProgressBar, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 30, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        setComponent(mainPanel);
        setMenuBar(menuBar);
        setStatusBar(statusPanel);
    }// </editor-fold>//GEN-END:initComponents

    private void startConversionButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_startConversionButtonMouseReleased
        conversionSettingsDialog.setVisible(false);
        conversionFact = Float.parseFloat(conversionFactorField.getText());
        doProlineConversion();
}//GEN-LAST:event_startConversionButtonMouseReleased

private void loadButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_loadButtonMouseReleased
    createImportDialog();
    loadSettingsFrame.setVisible(false);
    loadFiles(file_array); // TODO add your handling code here:
}//GEN-LAST:event_loadButtonMouseReleased

private void applyCorrectionFactorMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_applyCorrectionFactorMouseReleased
    correctionDialog.setVisible(false);
    doCorrectionFactor(Float.parseFloat(correctionFactorField.getText()));
}//GEN-LAST:event_applyCorrectionFactorMouseReleased

private void testButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_testButtonActionPerformed
    // TODO add your handling code here:
}//GEN-LAST:event_testButtonActionPerformed

    private void createImportDialog() {
        proteinNameColNumber = Integer.parseInt(proteinNameInput.getText());
        peptideSeqColNumber = Integer.parseInt(sequenceField.getText());
        peptideModColNumber = Integer.parseInt(modsField.getText());
        peptideSignalAColNumber = Integer.parseInt(areaAfield.getText());
        peptideSignalBColNumber = Integer.parseInt(areaBfield.getText());
        proteinDescriptionColumn = Integer.parseInt(descriptionInput.getText());
        //proteinDescriptionColumn = 0;
        javax.swing.table.DefaultTableModel loadModel = new javax.swing.table.DefaultTableModel();
        String[] item = new String[1];
        item[0] = peptideHeaders[proteinNameColNumber];
        loadModel.addColumn("protein ID", item);
        item[0] = peptideHeaders[peptideSeqColNumber];
        loadModel.addColumn("sequence", item);
        item[0] = peptideHeaders[peptideModColNumber];
        loadModel.addColumn("peptide mods", item);
        item[0] = peptideHeaders[peptideSignalAColNumber];
        loadModel.addColumn("Area/Signal A", item);
        item[0] = peptideHeaders[peptideSignalBColNumber];
        loadModel.addColumn("Area/Signal B", item);
        item[0] = peptideHeaders[proteinDescriptionColumn];
        loadModel.addColumn("Description", item);
        loadTable.setModel(loadModel);
        proteinNameInput.setText(String.valueOf(proteinNameColNumber));
        areaAfield.setText(String.valueOf(peptideSignalAColNumber));
        areaBfield.setText(String.valueOf(peptideSignalBColNumber));
        sequenceField.setText(String.valueOf(peptideSeqColNumber));
        modsField.setText(String.valueOf(peptideModColNumber));
        descriptionInput.setText(String.valueOf(proteinDescriptionColumn));
    }

private void testButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_testButtonMouseReleased
    createImportDialog();
}//GEN-LAST:event_testButtonMouseReleased

private void proteinNameInputActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_proteinNameInputActionPerformed
    // TODO add your handling code here:
}//GEN-LAST:event_proteinNameInputActionPerformed

private void FileMenuActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_FileMenuActionPerformed
    // TODO add your handling code here:
}//GEN-LAST:event_FileMenuActionPerformed

private void CloseMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_CloseMouseReleased
    comparisonDialog.setVisible(false);
}//GEN-LAST:event_CloseMouseReleased

private void SaveItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_SaveItemMouseReleased
}//GEN-LAST:event_SaveItemMouseReleased

private void plotMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_plotMenuItemMouseReleased
    plotGraph();
// TODO add your handling code here:
}//GEN-LAST:event_plotMenuItemMouseReleased

private void CrossExperimentMenuMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_CrossExperimentMenuMouseReleased
    doCrossExperimentComparison();
}//GEN-LAST:event_CrossExperimentMenuMouseReleased

private void prolineconverisonMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_prolineconverisonMenuItemMouseReleased
    conversionSettingsDialog.setVisible(true);
    conversionSettingsDialog.pack();
}//GEN-LAST:event_prolineconverisonMenuItemMouseReleased

private void normalizeMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_normalizeMenuItemMouseReleased
    normalizeExperiments();
}//GEN-LAST:event_normalizeMenuItemMouseReleased

private void normalizeAgainstFactorMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_normalizeAgainstFactorMouseReleased
    correctionDialog.setVisible(true);
    correctionDialog.pack();
}//GEN-LAST:event_normalizeAgainstFactorMouseReleased

private void normalizeActiveMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_normalizeActiveMenuItemMouseReleased
    normalizeActiveExperiment(); // TODO add your handling code here:
}//GEN-LAST:event_normalizeActiveMenuItemMouseReleased

private void exitMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_exitMenuItemActionPerformed
    System.exit(0);
}//GEN-LAST:event_exitMenuItemActionPerformed

private void LoadMenuActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_LoadMenuActionPerformed
    JFileChooser loadFileChooser = new JFileChooser();
    loadFileChooser.setFileSelectionMode(JFileChooser.FILES_ONLY);
    loadFileChooser.setMultiSelectionEnabled(true);
    loadFileChooser.setFileFilter(new FileFilter() {

        @Override
        public boolean accept(File f) {
            return f.getName().endsWith(".txt") || f.getName().endsWith(".msq") || f.isDirectory();
        }

        @Override
        public String getDescription() {
            return "tab delimited TXT file or MSQ file (MSQuant)";
        }
    });

    useParserName = "MSQuant";
    int userResponse = loadFileChooser.showOpenDialog(this.getFrame());
    if (userResponse == JFileChooser.APPROVE_OPTION) {

        file_array = loadFileChooser.getSelectedFiles();

        if (file_array.length >= 1) {
            loadSettingsFrame.setVisible(true);
            loadSettingsFrame.pack();
            //loadFiles(file_array);
            // CREATE THE CONTENT FOR OUR LoadSettings frame

            // RESET CHECKBOXES
            addPeptideAreasCHeckBox.setSelected(false);
            PTMinfoCheckbox.setSelected(false);
            peptideReportCheck.setSelected(false);
            useXICcheck.setSelected(false);
            reverseLabel.setSelected(false);

            // LOAD HEADERNAMES
            readPropertiesFile();
            //setColumnHeadeNames();
            javax.swing.table.DefaultTableModel loadModel = new javax.swing.table.DefaultTableModel();

            final ProtsAndPepsDataHandler data = new ProtsAndPepsDataHandler();
            // open file with msquant defaults
            data.setFileName(file_array[0].getAbsolutePath());

            /** Find the right columns */
            data.getMSQColumns();

            peptideHeaders = data.getMSQuantHeader();
            peptideSeqColNumber = data.headerIndex(sequence_header);
            peptideModColNumber = data.headerIndex(modification_header);
            peptideSignalAColNumber = data.headerIndex(signal1_header);

            /** 16 dec 2008, it is possible to have more than 1 label) Therefore more columns can/will exist.
             * Lets look at this while parsing
             */
            String signal3_header = "Intensity 3";
            String signal4_header = "Intensity 4";
            String signal_colnrs = "";
            if (data.headerIndex(signal4_header) > 0) {
                signal_colnrs = signal4_header + " at " + data.headerIndex(signal4_header);
            }
            if (data.headerIndex(signal3_header) > 0) {
                signal_colnrs = signal3_header + " at " + data.headerIndex(signal3_header) + " and " + signal4_header + " at " + data.headerIndex(signal4_header);
            }
            if (data.headerIndex(signal2_header) > 0) {
            }
            jLabel21.setText("Multiple signal columns detected: " + signal_colnrs);

            if (data.headerIndex(signal4_header) > 0) {
                peptideSignalBColNumber = data.headerIndex(signal4_header);
            } else if (data.headerIndex(signal3_header) > 0) {
                peptideSignalBColNumber = data.headerIndex(signal3_header);
            } else {
                peptideSignalBColNumber = data.headerIndex(signal2_header);
            }

            proteinNameColNumber = data.headerIndex(proteinid_header);
            proteinDescriptionColumn = data.headerIndex(proteindescription_header);
            ScanNumberColNumber = data.headerIndex(scannumber_header);
            QueryColNumber = data.headerIndex(querynumber_header);
            pepScoreColNumber = data.headerIndex(peptidescore_header);


            PTMpositionColNumber = data.headerIndex(ptminfo_header);
            if (PTMpositionColNumber > 0) {
                // set some flag for the parser!!
                PTMinfoCheckbox.setSelected(false);
            }

            useXICcheck.addMouseListener(new MouseListener() {

                @Override
                public void mouseClicked(MouseEvent e) {
                }

                @Override
                public void mousePressed(MouseEvent e) {
                }

                @Override
                public void mouseReleased(MouseEvent e) {

                    if (useXICcheck.isSelected()) {
                        peptideSignalAColNumber = data.headerIndex(xic1_header);

                        /** 16 dec 2008, when more than one labl */
                        String xic3_header = "XIC 3 [Da*secs]";
                        String xic4_header = "XIC 4 [Da*secs]";
                        String signal_colnrs = "";
                        if (data.headerIndex(xic4_header) > 0) {
                            peptideSignalBColNumber = data.headerIndex(xic4_header);
                        } else if (data.headerIndex(xic3_header) > 0) {
                            peptideSignalBColNumber = data.headerIndex(xic3_header);
                        } else {
                            peptideSignalBColNumber = data.headerIndex(xic2_header);
                        }
                        if (data.headerIndex(xic4_header) > 0) {
                            signal_colnrs = xic4_header + " at " + data.headerIndex(xic4_header);
                        }
                        if (data.headerIndex(xic3_header) > 0) {
                            signal_colnrs = xic3_header + " at " + data.headerIndex(xic3_header) + " and " + xic4_header + " at " + data.headerIndex(xic4_header);
                        }
                        if (data.headerIndex(signal2_header) > 0) {
                        }
                        jLabel21.setText("Multiple XIC columns detected: " + signal_colnrs);
                    } else {
                        peptideSignalAColNumber = data.headerIndex(signal1_header);

                        /** 16 dec 2008, when more than one labl */
                        String signal3_header = "Intensity 3";
                        String signal4_header = "Intensity 4";
                        if (data.headerIndex(signal4_header) > 0) {
                            peptideSignalBColNumber = data.headerIndex(signal4_header);
                        } else if (data.headerIndex(signal3_header) > 0) {
                            peptideSignalBColNumber = data.headerIndex(signal3_header);
                        } else {
                            peptideSignalBColNumber = data.headerIndex(signal2_header);
                        }

                        String signal_colnrs = "";
                        if (data.headerIndex(signal4_header) > 0) {
                            signal_colnrs = signal4_header + " at " + data.headerIndex(signal4_header);
                        }
                        if (data.headerIndex(signal3_header) > 0) {
                            signal_colnrs = signal3_header + " at " + data.headerIndex(signal3_header) + " and  " + signal4_header + " at " + data.headerIndex(signal4_header);
                        }
                        if (data.headerIndex(signal2_header) > 0) {
                        }
                        jLabel21.setText("Multiple signal columns detected: " + signal_colnrs);
                    }
                    areaAfield.setText(String.valueOf(peptideSignalAColNumber));
                    areaBfield.setText(String.valueOf(peptideSignalBColNumber));

                    createImportDialog();
                }

                @Override
                public void mouseEntered(MouseEvent e) {
                    //        throw new UnsupportedOperationException("Not supported yet.");
                }

                @Override
                public void mouseExited(MouseEvent e) {
                    //        throw new UnsupportedOperationException("Not supported yet.");
                }
            });

            peptideReportCheck.addMouseListener(new MouseListener() {

                @Override
                public void mouseClicked(MouseEvent e) {
                    //         throw new UnsupportedOperationException("Not supported yet.");
                }

                @Override
                public void mousePressed(MouseEvent e) {
                    //          throw new UnsupportedOperationException("Not supported yet.");
                }

                @Override
                public void mouseReleased(MouseEvent e) {
                    if (peptideReportCheck.isSelected()) {
                        proteinNameColNumber = data.headerIndex("Sequence");
                        peptideSeqColNumber = data.headerIndex("Sequence");
                        proteinDescriptionColumn = data.headerIndex("Accession number");
                    //  System.out.println("Checked: "+proteinDescriptionColumn);
                    } else {
                        proteinNameColNumber = data.headerIndex("Accession number");
                        peptideSeqColNumber = data.headerIndex("Sequence");
                        proteinDescriptionColumn = data.headerIndex("Description");
                    }
                    proteinNameInput.setText(String.valueOf(proteinNameColNumber));
                    sequenceField.setText(String.valueOf(peptideSeqColNumber));
                    descriptionInput.setText(String.valueOf(proteinDescriptionColumn));
                    createImportDialog();
                }

                @Override
                public void mouseEntered(MouseEvent e) {
                    //        throw new UnsupportedOperationException("Not supported yet.");
                }

                @Override
                public void mouseExited(MouseEvent e) {
                    //        throw new UnsupportedOperationException("Not supported yet.");
                }
            });

            String[] item = new String[1];
            item[0] = peptideHeaders[proteinNameColNumber];
            loadModel.addColumn("protein ID", item);
            item[0] = peptideHeaders[peptideSeqColNumber];
            loadModel.addColumn("sequence", item);
            item[0] = peptideHeaders[peptideModColNumber];
            loadModel.addColumn("peptide mods", item);
            item[0] = peptideHeaders[peptideSignalAColNumber];
            loadModel.addColumn("Area/Signal A", item);
            item[0] = peptideHeaders[peptideSignalBColNumber];
            loadModel.addColumn("Area/Signal B", item);
            item[0] = peptideHeaders[proteinDescriptionColumn];
            loadModel.addColumn("Description", item);


            loadTable.setModel(loadModel);
            proteinNameInput.setText(String.valueOf(proteinNameColNumber));
            areaAfield.setText(String.valueOf(peptideSignalAColNumber));
            areaBfield.setText(String.valueOf(peptideSignalBColNumber));
            sequenceField.setText(String.valueOf(peptideSeqColNumber));
            modsField.setText(String.valueOf(peptideModColNumber));
            descriptionInput.setText(String.valueOf(proteinDescriptionColumn));
        }
    }
}//GEN-LAST:event_LoadMenuActionPerformed

private void fastaPeptidetestMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_fastaPeptidetestMenuItemActionPerformed
    FastaHeaderRegexes reg = FastaHeaderRegexes.getInstance();
    for (String description : reg.getDescriptions()) {
        regexChooser.addItem(description);
    }
    fastaFileChooser.setFileFilter(new FileFilter() {

        @Override
        public boolean accept(File pathname) {
            boolean fa = pathname.getName().endsWith(".fa");
            boolean fasta = pathname.getName().endsWith(".fasta");
            boolean dir = pathname.isDirectory();
            return fa || fasta || dir;
        }

        @Override
        public String getDescription() {
            return "Fasta file (*.fa, *.fasta)";
        }
    });

    fastaCompareDialog.setModalityType(ModalityType.APPLICATION_MODAL);
    fastaCompareDialog.setVisible(true);
}//GEN-LAST:event_fastaPeptidetestMenuItemActionPerformed

private void close(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_close
    fastaCompareDialog.setVisible(false);
}//GEN-LAST:event_close

    /**
     * The action handler for the filter button in the Fasta filter dialog
     * @param evt action event
     */
private void filterButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_filterButtonActionPerformed
    if (fastaFileChooser.getSelectedFile() != null) {
        fastaCompareDialog.setVisible(false);
        try {
            update(null, new ProcessPreparingEvent());
            int activeExp = TopTabPane.getSelectedIndex();
            ProtsAndPepsDataHandler dataHandler = experiments.get(activeExp);
            FastaHeaderRegexes regexes = FastaHeaderRegexes.getInstance();

            FastaChecker checker = new FastaChecker();
            checker.setObserver(this);
            checker.check(dataHandler, fastaFileChooser.getSelectedFile(), regexes.getRegex((String) regexChooser.getSelectedItem()));

        //  updateTable(activeExp);
        } catch (FileNotFoundException ex) {
            Logger.getLogger(StatQuantGuiView.class.getName()).log(Level.SEVERE, null, ex);
        } catch (IOException ex) {
            Logger.getLogger(StatQuantGuiView.class.getName()).log(Level.SEVERE, null, ex);
        }
    }
}//GEN-LAST:event_filterButtonActionPerformed

    /**
     * function to update the table model of a certain experiment pane
     * @param number the number of the pane (not checked)
     */
    private void updateTable(int number) {
        ProtsAndPepsDataHandler handler = experiments.get(number);
        ExperimentPanel jTT = (ExperimentPanel) TopTabPane.getComponentAt(number);
        DefaultTableModel newModel = makeTable(handler);
        jTT.setDTM(newModel);
    }

    /**
     * function to update the table model of the currently active experiment pane
     *
     */
    private void updateTable() {
        updateTable(TopTabPane.getSelectedIndex());
    }

    /**
     * Handle the behavior of the filter button,
     * in response to the presence of a file name in the chooser
     */
private void fastaFileChooserPropertyChange(java.beans.PropertyChangeEvent evt) {//GEN-FIRST:event_fastaFileChooserPropertyChange
    if (evt.getPropertyName().equals(JFileChooser.SELECTED_FILE_CHANGED_PROPERTY)) {
        filterButton.setEnabled(!(evt.getNewValue() == null));
        String regex = (String) regexChooser.getSelectedItem();
        testRegex(regex);
    }
}//GEN-LAST:event_fastaFileChooserPropertyChange

private void regexChooserItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_regexChooserItemStateChanged
    if (evt.getStateChange() == ItemEvent.SELECTED) {
        testRegex((String) evt.getItem());
    }
}//GEN-LAST:event_regexChooserItemStateChanged

    /**
     * Test the regex by reading part of a chosen fasta file and
     */
    private void testRegex(String regexName) {
        if (fastaFileChooser.getSelectedFile() != null) {
            FastaParser parser = null;
            try {
                FastaHeaderRegexes reg = FastaHeaderRegexes.getInstance();

                parser = new FastaParser(fastaFileChooser.getSelectedFile());
                parser.setTitlePattern(reg.getRegex(regexName));
                regexLabel.setText(reg.getRegex(regexName));
                StringBuilder preview = new StringBuilder();
                for (int count = 0; count < 10; count++) {
                    //try to parse 10 sequences
                    FastaSequence seq = parser.getSequence(50); // Check with a maximum of 50 lines
                    if (seq == null) {
                        preview.append("<hr/><h3 style='color:gray>--End of file--</h3>");
                        break;
                    } else {
                        StringBuilder formattedSeq = new StringBuilder();
                        String origseq = seq.getSequence();
                        for (int strcount = 0; strcount < seq.getSequence().length(); strcount += 50) {
                            formattedSeq.append("  " + origseq.substring(strcount, strcount + 49 > origseq.length() ? origseq.length() : strcount + 49) + '\n');
                        }
                        preview.append("<h2>" + seq.getIdentifier() + "</h2>" + "<p style='margin-top: 0px; color:blue;'>" + seq.getDescription() + "</p>" + "<p><pre>" + formattedSeq.toString() + "</pre></p><hr/>");
                    }
                }
                fastapreview.setText(preview.toString());
                fastapreview.setCaretPosition(0);
            } catch (FileNotFoundException ex) {
                fastapreview.setText("<h1 style='color:red'>File not found</h1>");
            } catch (IOException ex) {
                fastapreview.setText("<h1 style='color:red'>File i/o error</h1>");
            } finally {
                try {
                    if (parser != null) {
                        parser.close();
                    }
                } catch (IOException ex) {
                    fastapreview.setText("<h1 style='color:red'>File close error</h1>");
                }
            }
        } else {
            fastapreview.setText("<h1>No file selected</h1>");
        }
    }

private void SaveReportItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_SaveReportItemMouseReleased

    JFileChooser saveReportFileDialot = new JFileChooser();

    int returnval = saveReportFileDialot.showSaveDialog(SaveReportItem);

    if (!(returnval == JFileChooser.CANCEL_OPTION)) {
        java.io.File saveFile = saveReportFileDialot.getSelectedFile();
        //jFileChooser1.
        int activeExp = TopTabPane.getSelectedIndex();
        ProtsAndPepsDataHandler dataHandler = experiments.get(activeExp);
        try {
            dataHandler.saveTotalReport(saveFile.getAbsolutePath());
        } catch (FileNotFoundException ex) {
            Logger.getLogger(StatQuantGuiView.class.getName()).log(Level.SEVERE, null, ex);
        }
    }
}//GEN-LAST:event_SaveReportItemMouseReleased

private void expNameFieldActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_expNameFieldActionPerformed
    // TODO add your handling code here:
}//GEN-LAST:event_expNameFieldActionPerformed

private void selectUnselectUniqueMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_selectUnselectUniqueMenuItemMouseReleased
    if (!experiments.get(TopTabPane.getSelectedIndex()).isFilteredForUniqueness_show()) {
        experiments.get(TopTabPane.getSelectedIndex()).selectOrUnselectUniquePeptides(false);
        experiments.get(TopTabPane.getSelectedIndex()).setFilteredForUniqueness_show(true);
    } else {
        experiments.get(TopTabPane.getSelectedIndex()).selectOrUnselectUniquePeptides(true);
        experiments.get(TopTabPane.getSelectedIndex()).setFilteredForUniqueness_show(false);
    }
    updateTable(TopTabPane.getSelectedIndex());
}//GEN-LAST:event_selectUnselectUniqueMenuItemMouseReleased

private void selectOutlierDetectionMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_selectOutlierDetectionMenuItemMouseReleased
    doOutlierDetection();
}//GEN-LAST:event_selectOutlierDetectionMenuItemMouseReleased

private void LoadGenericMenuMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_LoadGenericMenuMouseReleased
    JFileChooser loadGenericFileChooser = new JFileChooser();
    loadGenericFileChooser.setFileFilter(new FileFilter() {

        @Override
        public boolean accept(File f) {
            return f.getName().endsWith(".txt") || f.getName().endsWith(".msq") || f.isDirectory();
        }

        @Override
        public String getDescription() {
            return "tab delimited TXT file or MSQ file (MSQuant)";
        }
    });
    useParserName = "Generic";
    loadGenericFileChooser.showOpenDialog(LoadGenericMenu);
    file_array = loadGenericFileChooser.getSelectedFiles();
    loadSettingsFrame.setVisible(true);
    loadSettingsFrame.pack();
    //loadFiles(file_array);
    // CREATE THE CONTENT FOR OUR LoadSettings frame
    // RESET CHECKBOXES
    addPeptideAreasCHeckBox.setSelected(false);
    PTMinfoCheckbox.setSelected(false);
    peptideReportCheck.setSelected(false);
    useXICcheck.setSelected(false);
    reverseLabel.setSelected(false);

    if (file_array.length < 1) {
        loadSettingsFrame.setVisible(false);
    } else {
        javax.swing.table.DefaultTableModel loadModel = new javax.swing.table.DefaultTableModel();

        final ProtsAndPepsDataHandler DH = new ProtsAndPepsDataHandler();
        // open file with msquant defaults
        DH.setFileName(file_array[0].getAbsolutePath());

        /** Find the right columns */
        DH.getGenericColumns();
        if (readPropertiesFile()) {
            System.out.println("Using properties file");
            peptideHeaders = DH.getGenericHeader();
            peptideSeqColNumber = DH.headerIndex(sequence_header);
            peptideModColNumber = DH.headerIndex(modification_header);
            peptideSignalAColNumber = DH.headerIndex(signal1_header);
            peptideSignalBColNumber = DH.headerIndex(signal2_header);
            proteinNameColNumber = DH.headerIndex(proteinid_header);
            proteinDescriptionColumn = DH.headerIndex(proteindescription_header);
            ScanNumberColNumber = DH.headerIndex(scannumber_header);
            QueryColNumber = DH.headerIndex(querynumber_header);
        } else {
            peptideHeaders = DH.getGenericHeader();
            System.out.println("no properties from file are used, using default generics");
            pepScoreColNumber = DH.headerIndex("Score");
            peptideSeqColNumber = DH.headerIndex("Sequence");
            peptideModColNumber = DH.headerIndex("Modifications");
            peptideSignalAColNumber = DH.headerIndex("Intensity 1");
            peptideSignalBColNumber = DH.headerIndex("Intensity 2");
            proteinNameColNumber = DH.headerIndex("Accession Number");
            proteinDescriptionColumn = DH.headerIndex("Description");
            ScanNumberColNumber = 0;
            QueryColNumber = 0;
            pepScoreColNumber = DH.headerIndex("Score");
        }
        //  System.out.println(String.valueOf(peptideSignalAColNumber)+" <---");

        PTMpositionColNumber = 0;
        if (PTMpositionColNumber > 0) {
            // set some flag for the parser!!
            PTMinfoCheckbox.setSelected(false);
        } else {
            PTMinfoCheckbox.setEnabled(false);
        }
        useXICcheck.setEnabled(false);


        peptideReportCheck.addMouseListener(new MouseListener() {

            @Override
            public void mouseClicked(MouseEvent e) {
                //         throw new UnsupportedOperationException("Not supported yet.");
            }

            @Override
            public void mousePressed(MouseEvent e) {
                //          throw new UnsupportedOperationException("Not supported yet.");
            }

            @Override
            public void mouseReleased(MouseEvent e) {
                if (peptideReportCheck.isSelected()) {
                    proteinNameColNumber = DH.headerIndex("Sequence");
                    peptideSeqColNumber = DH.headerIndex("Sequence");
                    proteinDescriptionColumn = DH.headerIndex("Accession number");
                //  System.out.println("Checked: "+proteinDescriptionColumn);
                } else {
                    proteinNameColNumber = DH.headerIndex("Accession number");
                    peptideSeqColNumber = DH.headerIndex("Sequence");
                    proteinDescriptionColumn = DH.headerIndex("Description");
                }
                proteinNameInput.setText(String.valueOf(proteinNameColNumber));
                sequenceField.setText(String.valueOf(peptideSeqColNumber));
                descriptionInput.setText(String.valueOf(proteinDescriptionColumn));
                createImportDialog();
            }

            @Override
            public void mouseEntered(MouseEvent e) {
                //        throw new UnsupportedOperationException("Not supported yet.");
            }

            @Override
            public void mouseExited(MouseEvent e) {
                //        throw new UnsupportedOperationException("Not supported yet.");
            }
        });

        String[] item = new String[1];
        item[0] = peptideHeaders[proteinNameColNumber];
        loadModel.addColumn("protein ID", item);
        item[0] = peptideHeaders[peptideSeqColNumber];
        loadModel.addColumn("sequence", item);
        item[0] = peptideHeaders[peptideModColNumber];
        loadModel.addColumn("peptide mods", item);
        item[0] = peptideHeaders[peptideSignalAColNumber];
        loadModel.addColumn("Area/Signal A", item);
        item[0] = peptideHeaders[peptideSignalBColNumber];
        loadModel.addColumn("Area/Signal B", item);
        item[0] = peptideHeaders[proteinDescriptionColumn];
        loadModel.addColumn("Description", item);


        loadTable.setModel(loadModel);
        proteinNameInput.setText(String.valueOf(proteinNameColNumber));
        areaAfield.setText(String.valueOf(peptideSignalAColNumber));
        areaBfield.setText(String.valueOf(peptideSignalBColNumber));
        sequenceField.setText(String.valueOf(peptideSeqColNumber));
        modsField.setText(String.valueOf(peptideModColNumber));
        descriptionInput.setText(String.valueOf(proteinDescriptionColumn));


    }

}//GEN-LAST:event_LoadGenericMenuMouseReleased

private void SaveTabActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_SaveTabActionPerformed

    JFileChooser saveTabFileChooser = new JFileChooser();
    int returnval = saveTabFileChooser.showSaveDialog(SaveMenuItem);
    if (!(returnval == JFileChooser.CANCEL_OPTION)) {
        java.io.File saveFile = saveTabFileChooser.getSelectedFile();

        saveActivePeptideTable(saveFile.getAbsolutePath());
    }
}//GEN-LAST:event_SaveTabActionPerformed

private void AboutActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_AboutActionPerformed
    SplashScreen splash = new SplashScreen(true);
    splash.setVisible(true);
}//GEN-LAST:event_AboutActionPerformed

private void SaveItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_SaveItemActionPerformed

    // SAVE TABLE
    // open save dialog
    JFileChooser saveFileChooser = new JFileChooser();
    int returnval = saveFileChooser.showSaveDialog(SaveItem);

    if (returnval == JFileChooser.APPROVE_OPTION) {

        File savefile = saveFileChooser.getSelectedFile();
        String file = savefile.getAbsolutePath();

        if (!file.endsWith(".txt")) {
            file = file + ".txt";
        }

        javax.swing.table.DefaultTableModel newTablemodel = (DefaultTableModel) proteinComparisonTable.getModel();

        FileOutputStream out; // declare a file output object
        PrintStream p; // declare a print stream object
        try {
            // Create a new file output stream
            // connected to "myfile.txt"
            out = new FileOutputStream(file);
            // Connect print stream to the output stream
            p = new PrintStream(out);
            // save table to file
            // first get table
            Vector data = newTablemodel.getDataVector(); // table as vector
            // how many columns ? etc
            int colnumbers = newTablemodel.getColumnCount();
            int rownumbers = newTablemodel.getRowCount();
            int colcount = 0;
            int rowcount = 0;
            // headers ?
            for (colcount = 0; colcount < colnumbers; colcount++) {
                p.print(newTablemodel.getColumnName(colcount));
                p.print("\t");
            }
            p.println();
            // iterate through array (vector)
            for (rowcount = 0; rowcount < rownumbers; rowcount++) {
                for (colcount = 0; colcount < colnumbers; colcount++) {
                    if (((Vector) data.get(rowcount)).get(colcount) == null) {
                        p.print("\t");
                    } else {
                        p.print(((Vector) data.get(rowcount)).get(colcount));
                        p.print("\t");
                    }
                }
                p.println();
            }
            p.close();
        } catch (Exception e) {
            System.err.println("Error writing to file");
        }
    }
}//GEN-LAST:event_SaveItemActionPerformed

private void closeMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_closeMenuItemActionPerformed
    removeCurrentExperiment();
}//GEN-LAST:event_closeMenuItemActionPerformed

private void toolsMenuActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_toolsMenuActionPerformed
    // TODO add your handling code here:
}//GEN-LAST:event_toolsMenuActionPerformed

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JTabbedPane BottomTabPane;
    private javax.swing.JMenuItem Close;
    private javax.swing.JMenuItem CrossExperimentMenu;
    private javax.swing.JMenu FileMenu;
    private javax.swing.JMenuItem LoadGenericMenu;
    private javax.swing.JMenuItem LoadMenu;
    private javax.swing.JCheckBox PTMinfoCheckbox;
    private javax.swing.JMenuItem SaveItem;
    private javax.swing.JMenuItem SaveMenuItem;
    private javax.swing.JMenuItem SaveReportItem;
    private javax.swing.JTabbedPane TopTabPane;
    private javax.swing.JCheckBox addPeptideAreasCHeckBox;
    private javax.swing.JButton applyCorrectionFactor;
    private javax.swing.JTextField areaAfield;
    private javax.swing.JTextField areaBfield;
    private javax.swing.JButton closeButton;
    private javax.swing.JMenuItem closeMenuItem;
    private javax.swing.JDialog comparisonDialog;
    private javax.swing.JScrollPane comparisonScrollpane;
    private javax.swing.JTextArea conversionFactor;
    private javax.swing.JTextField conversionFactorField;
    private javax.swing.JDialog conversionSettingsDialog;
    private javax.swing.JDialog correctionDialog;
    private javax.swing.JTextField correctionFactorField;
    private javax.swing.JTextField descriptionInput;
    private javax.swing.JProgressBar eventProgressBar;
    private javax.swing.JTextField expNameField;
    private javax.swing.JMenuItem exportExcelTab;
    private javax.swing.JMenuItem exportExcelTabPeps;
    private javax.swing.JMenu exportMenu;
    private javax.swing.JDialog fastaCompareDialog;
    private javax.swing.JFileChooser fastaFileChooser;
    private javax.swing.JMenuItem fastaPeptidetestMenuItem;
    private javax.swing.JScrollPane fastaScroller;
    private javax.swing.JTextPane fastapreview;
    private javax.swing.JButton filterButton;
    private javax.swing.JMenu helpMenu;
    private javax.swing.JButton jButton1;
    private javax.swing.JButton jButton2;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel10;
    private javax.swing.JLabel jLabel11;
    private javax.swing.JLabel jLabel12;
    private javax.swing.JLabel jLabel13;
    private javax.swing.JLabel jLabel14;
    private javax.swing.JLabel jLabel15;
    private javax.swing.JLabel jLabel16;
    private javax.swing.JLabel jLabel17;
    private javax.swing.JLabel jLabel18;
    private javax.swing.JLabel jLabel19;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel20;
    private javax.swing.JLabel jLabel21;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JLabel jLabel7;
    private javax.swing.JLabel jLabel8;
    private javax.swing.JLabel jLabel9;
    private javax.swing.JMenuBar jMenuBar2;
    private javax.swing.JMenuItem jMenuItem1;
    private javax.swing.JMenuItem jMenuItem2;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JPanel jPanel3;
    private javax.swing.JPanel jPanel4;
    private javax.swing.JPanel jPanel5;
    private javax.swing.JPanel jPanel6;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JScrollPane jScrollPane3;
    private javax.swing.JSeparator jSeparator1;
    private javax.swing.JSeparator jSeparator2;
    private javax.swing.JSeparator jSeparator3;
    private javax.swing.JSeparator jSeparator4;
    private javax.swing.JSeparator jSeparator5;
    private javax.swing.JSplitPane jSplitPane1;
    private javax.swing.JTextPane jTextPane1;
    private javax.swing.JButton loadButton;
    private javax.swing.JScrollPane loadScrollPane;
    private javax.swing.JFrame loadSettingsFrame;
    private javax.swing.JTable loadTable;
    private javax.swing.JPanel mainPanel;
    private javax.swing.JMenuBar menuBar;
    private javax.swing.JTextField modsField;
    private javax.swing.JMenuItem normalizeActiveMenuItem;
    private javax.swing.JMenuItem normalizeAgainstFactor;
    private javax.swing.JMenuItem normalizeMenuItem;
    private javax.swing.JPanel peptidePanel;
    private javax.swing.JCheckBox peptideReportCheck;
    private javax.swing.JTable peptideTable;
    private javax.swing.JScrollPane peptideTableScroller;
    private javax.swing.JMenuItem plotMenuItem;
    private javax.swing.JProgressBar progressBar;
    private javax.swing.JDialog progressDialog;
    private javax.swing.JMenuItem prolineconverisonMenuItem;
    private javax.swing.JTable proteinComparisonTable;
    private javax.swing.JTextField proteinNameInput;
    private javax.swing.JLabel proteinTextField;
    private javax.swing.JComboBox regexChooser;
    private javax.swing.JLabel regexLabel;
    private javax.swing.JCheckBox reverseLabel;
    private javax.swing.JMenuItem selectOutlierDetectionMenuItem;
    private javax.swing.JMenuItem selectUnselectUniqueMenuItem;
    private javax.swing.JTextField sequenceField;
    private javax.swing.JButton startConversionButton;
    private javax.swing.JLabel statusAnimationLabel;
    private javax.swing.JLabel statusMessageLabel;
    private javax.swing.JPanel statusPanel;
    private javax.swing.JButton testButton;
    private javax.swing.JMenu toolsMenu;
    private javax.swing.JCheckBox useXICcheck;
    // End of variables declaration//GEN-END:variables
    private final Timer messageTimer;
    private final Timer busyIconTimer;
    private final Icon idleIcon;
    private final Icon[] busyIcons = new Icon[15];
    private int busyIconIndex = 0;
    private ProtsAndPepsDataHandler PPDH = new ProtsAndPepsDataHandler();
    private JDialog aboutBox;
    private ArrayList<ProtsAndPepsDataHandler> experiments = new ArrayList<ProtsAndPepsDataHandler>();
    private java.io.File[] file_array;
    // DECLARE HERE THE VARIABLES NEEDED TO STORE THE USER SETTING FOR THE PARSER
    private int peptideSeqColNumber = 0;
    /** Column with the peptide sequence */
    private int peptideModColNumber = 0;
    /** Column with the modification information */
    private int peptideSignalAColNumber = 0;
    /** Column with the signal for the light peptide */
    private int peptideSignalBColNumber = 0;
    /** Column with the signal for the heavy peptide */
    private int proteinNameColNumber = 0;
    /** COlumn with the (protein) name (or ID) */
    private int proteinDescriptionColumn = 0;
    /** Column number with the protein Description */
    private int PTMpositionColNumber = 0;
    /** MSQuant specific, it has a checked PTMinfo column */
    private int ScanNumberColNumber = 0;
    /** this is actually the RAW filename stored in the quantitationreport */
    private int QueryColNumber = 0;
    /** QueryNnumber */
    private int pepScoreColNumber = 0;
    /** Score for the peptide */
    // DECLARE (STRING) VARIABLES FOR THE COLUMN HEAFERS!
    private String proteinid_header = "";
    private String proteindescription_header = "";
    private String sequence_header = "";
    private String modification_header = "";
    private String signal1_header = "";
    private String signal2_header = "";
    private String xic1_header = "";
    private String xic2_header = "";
    private String ptminfo_header = "";
    private String scannumber_header = "";
    private String querynumber_header = "";
    private String peptidescore_header = "";
    // END
    private String[] peptideHeaders;
    /** The headers in the quantitation report file */
    private float conversionFact = 0f;
    private ArrayList<Boolean> expHasPconversion = new ArrayList<Boolean>();
    private String useParserName = "Generic";

    /** Is an experiment already checked for Proline conversion? */
    /**
     *   A function to read a propertiesfile
     */
    private boolean readPropertiesFile() {
        Properties properties = new Properties();
        try {
            properties.load(new FileInputStream("StatQuant.properties"));

            Iterator it = properties.keySet().iterator();
            while (it.hasNext()) {
                String name = it.next().toString();
                System.out.println(name + " " + properties.get(name));
            }



            statusMessageLabel.setText("Properties file read");
            if (useParserName.equals("MSQuant")) {
                statusMessageLabel.setText("Properties for MSQuant read");
                proteinid_header = properties.getProperty("proteinid_MSQ", "Accession number");
                proteindescription_header = properties.getProperty("proteindescription_MSQ", "Description");
                sequence_header = properties.getProperty("sequence_MSQ", "Sequence");
                modification_header = properties.getProperty("modification_MSQ", "Modifications");
                signal1_header = properties.getProperty("signal1_MSQ", "Intensity 1");
                signal2_header = properties.getProperty("signal2_MSQ", "Intensity 2");
                xic1_header = properties.getProperty("xic1_MSQ", "XIC 1 [Da*secs]");
                xic2_header = properties.getProperty("xic2_MSQ", "XIC 2 [Da*secs]");
                ptminfo_header = properties.getProperty("ptminfo_MSQ", "Checked PTM info");
                scannumber_header = properties.getProperty("scannumber_MSQ", "Raw file path");
                querynumber_header = properties.getProperty("querynumber_MSQ", "Query number");
                peptidescore_header = properties.getProperty("peptidescore_MSQ", "Score");
                return true;
            } else if (useParserName.equals("Generic")) {
                statusMessageLabel.setText("Properties for Generic read");
                proteinid_header = properties.getProperty("proteinid_Generic", "Accession number");
                proteindescription_header = properties.getProperty("proteindescription_Generic", "Description");
                sequence_header = properties.getProperty("sequence_Generic", "Sequence");
                modification_header = properties.getProperty("modification_Generic", "Modifications");
                signal1_header = properties.getProperty("signal1_Generic", "Intensity 1");
                signal2_header = properties.getProperty("signal2_Generic", "Intensity 2");
                xic1_header = properties.getProperty("xic1_Generic", "XIC 1 [Da*secs]");
                xic2_header = properties.getProperty("xic2_Generic", "XIC 2 [Da*secs]");
                scannumber_header = properties.getProperty("scannumber_Generic", "Raw file path");
                querynumber_header = properties.getProperty("querynumber_Generic", "Query number");
                peptidescore_header = properties.getProperty("peptidescore_Generic", "Score");
                return true;
            } else {
                setColumnHeadeNames();
                statusMessageLabel.setText("Cannot find properties, useing default columns");
                return false;
            }


        } catch (IOException e) {
            System.out.println("Cannot open properties file");
            statusMessageLabel.setText("Cannot open properties file");
            statusMessageLabel.setText(e.getMessage());
            setColumnHeadeNames();
            return false;
        }
    }

    /**
     *   A function to write a propertiesfile
     */
    private void writePropertiesFile() {
        // try {
        //    properties.store(new FileOutputStream("filename.properties"), null);
        //} catch (IOException e) {
        //}
    }

    /**
     * This function sets the Header names used for finding the right column numbers
     * The plan is to retreive these from a properties file.
     */
    private void setColumnHeadeNames() {
        proteinid_header = "Accession number";
        proteindescription_header = "Description";
        sequence_header = "Sequence";
        modification_header = "Modifications";
        signal1_header = "Intensity 1";
        signal2_header = "Intensity 2";
        xic1_header = "XIC 1 [Da*secs]";
        xic2_header = "XIC 2 [Da*secs]";
        ptminfo_header = "Checked PTM info";
        scannumber_header = "Raw file path";
        querynumber_header = "Query number";
        peptidescore_header = "Score";
    }

    /** This funtion normalizes against a user defined factor on the 2LOG ratio's !
     *  @factor is that number against which is normalized. It is substracted from the 2Log ratio's of all peptides! 
     */
    private void doCorrectionFactor(float factor) {
        //    if (!(TopTabPane.getTabCount() < 1)) {
        int activeExp = TopTabPane.getSelectedIndex();
        PPDH = experiments.get(activeExp);
        statusMessageLabel.setText("Normalizing experiment against a factor");
        float oldMedian = PPDH.normalizeLogRatiosAgainstFactor(factor);
        javax.swing.table.DefaultTableModel dTM = makeTable(PPDH);
        ExperimentPanel jTT = (ExperimentPanel) TopTabPane.getComponentAt(activeExp);
        TopTabPane.setTitleAt(activeExp, TopTabPane.getTitleAt(activeExp) + "  Median:" + Float.toString(oldMedian));
        jTT.setDTM(dTM);
        statusMessageLabel.setText("Median for experiment " + (activeExp + 1) + " =" + String.valueOf(oldMedian));

    //} else {
    //    statusMessageLabel.setText("Please Load Experimental Data First..");
    // }
    }

    private void removeCurrentExperiment() {
        int number = TopTabPane.getSelectedIndex();
        TopTabPane.remove(number);
        experiments.remove(number);

    }

    private void loadFiles(java.io.File[] files) {
        if (files.length < 1) {
            statusMessageLabel.setText("You have not selected a file..");
        } else {
            // Loading is nice... However we need to be sure that all settings are ok?
            // TODO IMPLEMENT HEADER CHECK TO CHECK FOR THE RIGHT COLUMNS
            // create a popup with a table and the header in there
            // This check is performed in the loadSettings Frame... the global variables are updated
            int experimentNumbers = experiments.size();

            experiments.add(experimentNumbers, new ProtsAndPepsDataHandler());
            // SET ALL OPTIONS FOR THE ProtsAndPepsDataHandler before submitting it to the JtabbedTable class.
            // is reversed label?
            if (reverseLabel.isSelected()) {
                int Sig1 = peptideSignalAColNumber;
                int Sig2 = peptideSignalBColNumber;
                peptideSignalAColNumber = Sig2;
                peptideSignalBColNumber = Sig1;
            }
            // Checkbox: addPeptideAreas
            if (addPeptideAreasCHeckBox.isSelected()) {
                // Set the parser to ADD mode!
                experiments.get(experimentNumbers).setUseUniquePeptidesOnly(true);
            }

            for (int t = 0; t < files.length; t++) {
                statusMessageLabel.setText("Loading: " + files[t].getAbsolutePath());
                experiments.get(experimentNumbers).setFileName(files[t].getAbsolutePath());

                if (PTMinfoCheckbox.isSelected()) {
                    experiments.get(experimentNumbers).setPTMpositionColNumber(PTMpositionColNumber);
                }
                if (ScanNumberColNumber > 0) {
                    experiments.get(experimentNumbers).setScanNumberColNumber(ScanNumberColNumber);
                }

                if (pepScoreColNumber > 0) {
                    experiments.get(experimentNumbers).setPepScoreColNumber(pepScoreColNumber);
                }
                if (QueryColNumber > 0) {
                    experiments.get(experimentNumbers).setQueryColNumber(QueryColNumber);
                }
                if (peptideReportCheck.isSelected()) {
                    experiments.get(experimentNumbers).setUsePeptideReport(true);
                }


                experiments.get(experimentNumbers).setProteinNameColumn(proteinNameColNumber);
                experiments.get(experimentNumbers).setProtDescriptionColumn(proteinDescriptionColumn);
                experiments.get(experimentNumbers).setPeptideColumn(peptideSeqColNumber);
                experiments.get(experimentNumbers).setModificationColumn(peptideModColNumber);
                experiments.get(experimentNumbers).setPeptideSignalA(peptideSignalAColNumber);
                experiments.get(experimentNumbers).setPeptideSignalB(peptideSignalBColNumber);

                // Here we have to choose the Parser we are going to use.
                if (useParserName.equals("Generic")) {
                    experiments.get(experimentNumbers).runParser("generic");
                } else if (useParserName.equals("MSQuant")) {
                    experiments.get(experimentNumbers).runParser("MSQuantParser2");
                } else {
                    experiments.get(experimentNumbers).runParser("MSQuantParser2");
                }
            }
            statusMessageLabel.setText("Finished loading file(s)..");
            String Tabname = "Experiment " + experiments.size();
            if (!expNameField.getText().equals("")) {
                Tabname = expNameField.getText();
            }

            // BUILD THE TABLE WITH THE PARSED DATA: AUTO DISPLAY THIS IN A (NEW) TAB
            // The jTabbedPane class plays a role.
            // send the data, the target bottom table and the bottomTabpanel to it.
            TopTabPane.addTab(Tabname, new ExperimentPanel(experiments.get(experimentNumbers), peptideTable, BottomTabPane, correctionDialog, correctionFactorField));
        // RETREIVE/CALCULATE the column DATA for the Table
        }
    }

    private void plotGraph() {
        int activeExp = TopTabPane.getSelectedIndex();
        ProtsAndPepsDataHandler pDH = experiments.get(activeExp);

        XYSeries XY = new XYSeries("MA P<0.05");
        XYSeries XY2 = new XYSeries("MA P>p0.05");
        Iterator<String> it = pDH.getProtsAndPeps().keySet().iterator();
        while (it.hasNext()) {
            String protID = it.next();
            Float[] MA = pDH.getMAvalues(protID);
            float PVAL = pDH.getProteinPvalue(protID, 2, 0.05f, 1.0d);

            if (PVAL <= 0.05) {
                XY.add(MA[0], MA[1]);
            } else {
                XY2.add(MA[0], MA[1]);
            }
        }
        XYSeriesCollection dataset = new XYSeriesCollection();
        dataset.addSeries(XY);
        dataset.addSeries(XY2);
        JFreeChart chart = ChartFactory.createScatterPlot("MA plot", "A", "M", dataset, PlotOrientation.VERTICAL, true, false, false);

        ChartFrame cframe = new ChartFrame("MA plot", chart);
        cframe.pack();
        cframe.setVisible(true);
    }

    private javax.swing.table.DefaultTableModel makeTable(ProtsAndPepsDataHandler DH) {
        ProtsAndPepsDataHandler pDH = DH;
        ArrayList<Integer> number = new ArrayList<Integer>();
        ArrayList<Float> ratios = new ArrayList<Float>();
        ArrayList<Float> stdevs = new ArrayList<Float>();
        ArrayList<Integer> nrpeptides = new ArrayList<Integer>();
        ArrayList<Float> tstats = new ArrayList<Float>();
        ArrayList<Float> Pvalues = new ArrayList<Float>();
        ArrayList<Float> logRatios = new ArrayList<Float>();
        Iterator<String> it = pDH.getProtsAndPeps().keySet().iterator();
        ArrayList<String> descriptions = new ArrayList<String>();
        int counter = 1;
        while (it.hasNext()) {
            String Prot = it.next();
            float ratio = pDH.getProteinRatio(Prot);
            ratios.add(ratio);
            //float logratio = (float) (Math.log10(ratio)/Math.log10(2));
            logRatios.add(pDH.getProteinLogRatio(Prot));
            stdevs.add(pDH.getProteinLogSTDEV(Prot));
            nrpeptides.add(pDH.getProteinPeptideNumber(Prot));
            //   tstats.add(experiments.get(experimentNumbers).getProteinTstatistics(experiments.get(experimentNumbers).getProteinSTDEV(Prot), experiments.get(experimentNumbers).getProteinPeptideNumber(Prot), experiments.get(experimentNumbers).getProteinRatio(Prot), 1f));
            Pvalues.add(pDH.getProteinLogPvalue(Prot, 2, 0.5f, 0d));
            number.add(counter);
            descriptions.add(pDH.getProteinDescription(Prot));
            counter++;
        }
        // BUILD THE TABLE MODEL
        ArrayList<Double> Qvalues = new ArrayList<Double>();
        qvalue qval = new qvalue(Pvalues.toArray(), Pvalues.size());
        double[] q1 = qval.q_values();
        for (int t = 0; t < q1.length; t++) {
            Qvalues.add(q1[t]);
        }



        javax.swing.table.DefaultTableModel DTM = new javax.swing.table.DefaultTableModel();
        DTM.addColumn("#", number.toArray());
        DTM.addColumn("protID", pDH.getProtsAndPeps().keySet().toArray());
        DTM.addColumn("Ratio", ratios.toArray());
        DTM.addColumn("log Ratio", logRatios.toArray());
        DTM.addColumn("(log) STDEV", stdevs.toArray());
        DTM.addColumn("nr peptides", nrpeptides.toArray());

        //  DTM.addColumn("T statistics", tstats.toArray());
        DTM.addColumn("P-value", Pvalues.toArray());
        DTM.addColumn("Qvalue", Qvalues.toArray());
        DTM.addColumn("Description", descriptions.toArray());
        return DTM;
    }

    private void doOutlierDetection() {
        if (!(TopTabPane.getTabCount() < 1)) {
            int activeExp = TopTabPane.getSelectedIndex();
            PPDH = experiments.get(activeExp);

            int totalOutliers = 0;
            int outliers = PPDH.doOutlierDetection();
            totalOutliers = outliers;
            while (outliers > 0) {
                outliers = PPDH.doOutlierDetection();
                totalOutliers = totalOutliers + outliers;
            }

            javax.swing.table.DefaultTableModel dTM = makeTable(PPDH);
            ExperimentPanel jTT = (ExperimentPanel) TopTabPane.getComponentAt(activeExp);
            jTT.setDTM(dTM);
            statusMessageLabel.setText("Outlier detection on " + activeExp + " using Z scores (n>3 Z>3) | Found " + totalOutliers + " Outliers...");
        } else {
            statusMessageLabel.setText("Please Load Experimental Data First..");
        }
    }

    private void normalizeActiveExperiment() {
        if (!(TopTabPane.getTabCount() < 1)) {
            int activeExp = TopTabPane.getSelectedIndex();
            PPDH = experiments.get(activeExp);
            statusMessageLabel.setText("Normalizing experiment " + activeExp + " against median values...");
            float oldMedian = PPDH.normalizeLogRatiosAgainstMedian();
            javax.swing.table.DefaultTableModel dTM = makeTable(PPDH);
            ExperimentPanel jTT = (ExperimentPanel) TopTabPane.getComponentAt(activeExp);
            TopTabPane.setTitleAt(activeExp, TopTabPane.getTitleAt(activeExp) + "  Median:" + Float.toString(oldMedian));
            jTT.setDTM(dTM);
            statusMessageLabel.setText("Median for experiment " + (activeExp + 1) + " =" + String.valueOf(oldMedian));
        } else {
            statusMessageLabel.setText("Please Load Experimental Data First..");
        }
    }

    private void normalizeExperiments() {
        // CHeck if there are any experiment!
        if (!(TopTabPane.getTabCount() < 1)) {
            statusMessageLabel.setText("Normalizing all experiments against median values...");
            for (int t = 0; t < TopTabPane.getTabCount(); t++) {
                PPDH = experiments.get(t);
                float oldMedian = PPDH.normalizeLogRatiosAgainstMedian();
                javax.swing.table.DefaultTableModel dTM = makeTable(PPDH);
                ExperimentPanel jTT = (ExperimentPanel) TopTabPane.getComponentAt(t);
                TopTabPane.setTitleAt(t, TopTabPane.getTitleAt(t) + "  Median:" + Float.toString(oldMedian));
                jTT.setDTM(dTM);
                statusMessageLabel.setText("Median for experiment " + (t + 1) + " =" + String.valueOf(oldMedian));
            }
        } else {
            statusMessageLabel.setText("Please Load Experimental Data First..");
        }
    }

    private void doProlineConversion() {
        // get active table and datahandler
        if (!(TopTabPane.getTabCount() < 1)) {
            int activeExp = TopTabPane.getSelectedIndex();
            if (experiments.get(activeExp).isIsPConverted()) {
                statusMessageLabel.setText("Experiment " + (activeExp + 1) + " has already been converted");
            } else {
                PPDH = experiments.get(activeExp);
                statusMessageLabel.setText("Correcting prolines in experiment " + activeExp);
                Iterator it = PPDH.getProtsAndPeps().keySet().iterator();
                while (it.hasNext()) {
                    PPDH.correctProlineConversion((String) it.next(), conversionFact);
                }
                javax.swing.table.DefaultTableModel dTM = makeTable(PPDH);
                ExperimentPanel jTT = (ExperimentPanel) TopTabPane.getComponentAt(activeExp);
                TopTabPane.setTitleAt(activeExp, TopTabPane.getTitleAt(activeExp) + "; P corrected");
                jTT.setDTM(dTM);
                PPDH.setIsPConverted(true);
                PPDH.setConversionFactor(conversionFact);
            // statusMessageLabel.setText("Median for experiment "+(activeExp+1)+" ="+String.valueOf(oldMedian));
            }
        } else {
            statusMessageLabel.setText("Please Load Experimental Data First..");
        }
    }

    /**
     * Retrieve the table model of the the currently selected
     * @return
     */
    private DefaultTableModel getActiveTableModel() {
        ExperimentPanel jTT = (ExperimentPanel) TopTabPane.getSelectedComponent();
        return jTT.getDefaultTableModel();
    }

    private void saveActivePeptideTable(String file) {
        //System.out.println(file);
        // Save Table ;
        // Find the Active TAB and its component (a jTabbedTable class which contains the table):
        DefaultTableModel newTablemodel = getActiveTableModel();
        FileOutputStream out; // declare a file output object
        PrintStream p; // declare a print stream object
        try {
            // Create a new file output stream
            // connected to "myfile.txt"
            out = new FileOutputStream(file);
            // Connect print stream to the output stream
            p = new PrintStream(out);
            // save table to file
            // first get table
            Vector data = newTablemodel.getDataVector(); // table as vector
            // how many columns ? etc
            int colnumbers = newTablemodel.getColumnCount();
            int rownumbers = newTablemodel.getRowCount();
            int colcount = 0;
            int rowcount = 0;
            // headers ?
            for (colcount = 0; colcount < colnumbers; colcount++) {
                p.print(newTablemodel.getColumnName(colcount));
                p.print("\t");
            }
            p.println();
            // iterate through array (vector)
            for (rowcount = 0; rowcount < rownumbers; rowcount++) {
                for (colcount = 0; colcount < colnumbers; colcount++) {
                    if (((Vector) data.get(rowcount)).get(colcount) == null) {
                        p.print("\t");
                    } else {
                        p.print(((Vector) data.get(rowcount)).get(colcount));
                        p.print("\t");
                    }
                }
                p.println();
            }
            p.close();
        } catch (Exception e) {
            System.err.println("Error writing to file");
        }
    } //end save

// In this function we take all proteins from all experiment. Try to find which proteins are shared in 2 or more experiments
// Get their ratio's and t-test them to find reliable up and down regulated proteins.
    private void doCrossExperimentComparison() {

        // STEP 1. We create a hashmap with all proteins. And add per experiment the ratio's
        // Null values if an experiment does not provide a ratio for a protein
        HashMap<String, ArrayList<Float>> CrosExpProt = new HashMap<String, ArrayList<Float>>();
        HashMap<String, String> protDesc = new HashMap<String, String>();
        for (int t = 0; t < TopTabPane.getTabCount(); t++) {
            // get the protein names, check if they exist.
            //  System.out.println("Processing Experiment: "+t);
            Iterator it = experiments.get(t).getProtsAndPeps().keySet().iterator();
            while (it.hasNext()) {
                String ProtID = (String) it.next();
                if (!(CrosExpProt.containsKey(ProtID))) {
                    protDesc.put(ProtID, experiments.get(t).getProteinDescription(ProtID));

                    ArrayList<Float> x = new ArrayList<Float>();
                    for (int u = 0; u < TopTabPane.getTabCount(); u++) {
                        x.add(u, null);
                    }
                    x.add(t, experiments.get(t).getProteinLogRatio(ProtID));
                    // x.add(t, 10f);
                    CrosExpProt.put(ProtID, x);
                } else {
                    // this protein already exists
                    ArrayList<Float> x = CrosExpProt.get(ProtID);
                    x.add(t, experiments.get(t).getProteinLogRatio(ProtID));
                }
            }
        }
        // Lets create a table with proteins and all ratio's
        javax.swing.table.DefaultTableModel TableModel = new javax.swing.table.DefaultTableModel();
        TableModel.addColumn("ProteinID");
        for (int t = 0; t < TopTabPane.getTabCount(); t++) {
            TableModel.addColumn(TopTabPane.getTitleAt(t)); // "Experiment " + (t + 1));
        }
        TableModel.addColumn("# ratios");
        TableModel.addColumn("Average 2Log(ratio)");
        TableModel.addColumn("P-value");


        Iterator it = CrosExpProt.keySet().iterator();
        ArrayList<Float> pvalues = new ArrayList<Float>();
        while (it.hasNext()) {
            java.lang.String ProtID = (java.lang.String) it.next();
            java.util.ArrayList<java.lang.String> row = new java.util.ArrayList<java.lang.String>();
            ArrayList<Float> ratios = new ArrayList<Float>();
            row.add(ProtID);
            int count = 0;

            for (int i = 0; i < TopTabPane.getTabCount(); i++) {
                Float F_list = CrosExpProt.get(ProtID).get(i);
                row.add(java.lang.String.valueOf(F_list));
                count++;
                String val = String.valueOf(F_list);
                if (val.equals("null")) {
                    //               System.out.println("null detected");
                } else {
                    ratios.add(Float.parseFloat(val));
                //               System.out.println("VAL = "+val);
                }
            }
            double[] ratio = new double[ratios.size()];
            float averatio = 0f;
            for (int o = 0; o < ratios.size(); o++) {
                ratio[o] = (double) ratios.get(o);
                averatio += ratios.get(o);
            }
            row.add(Integer.toString(ratios.size()));
            averatio = averatio / ratios.size();
            row.add(String.valueOf(averatio));
            float pVal = 1.0f;
            try {
                pVal = (float) org.apache.commons.math.stat.inference.TestUtils.tTest(1.0, ratio);
            // System.out.println(observed.length);
            } catch (IllegalArgumentException ex) {
            } catch (MathException ex) {
            }
            row.add(String.valueOf(pVal));
            pvalues.add(pVal);
            TableModel.addRow(row.toArray());
        }
        ArrayList<Double> Qvalues = new ArrayList<Double>();
        qvalue qval = new qvalue(pvalues.toArray(), pvalues.size());
        double[] q1 = qval.q_values();
        for (int t = 0; t < q1.length; t++) {
            Qvalues.add(q1[t]);
        }
        // TableModel.addColumn("Qvalues", Qvalues.toArray());

        it = CrosExpProt.keySet().iterator();
        ArrayList<String> desc = new ArrayList<String>();
        while (it.hasNext()) {
            desc.add(protDesc.get(it.next()));
        }

        TableModel.addColumn("Description", desc.toArray());
        proteinComparisonTable.setModel(TableModel);
        proteinComparisonTable.setAutoCreateRowSorter(true);
        comparisonDialog.setVisible(true);

        comparisonDialog.pack();
//    proteinComparisonFrame.setVisible(true);
//    proteinComparisonFrame.pack();
    }

    /**
     * Long-running events can register 'this' to send messages to the window
     * @param o observable returns the object that sent the event, ignored
     * @param arg the event that was sent
     */
    @Override
    public void update(Observable o, final Object arg) {

        if (arg instanceof ProcessingFinishedEvent) {
            SwingUtilities.invokeLater(new Runnable() {

                String message = ((ProcessingFinishedEvent) arg).getMessage();

                @Override
                public void run() {
                    progressDialog.setVisible(false);
                    JOptionPane.showMessageDialog(TopTabPane, message);
                    updateTable();
                }
            });
        }

        if (arg instanceof ProgressEvent) {
            SwingUtilities.invokeLater(new Runnable() {

                int progress = ((ProgressEvent) arg).getProgress();

                @Override
                public void run() {
                    progressDialog.setVisible(true);
                    eventProgressBar.setIndeterminate(false);
                    if (eventProgressBar.getValue() != progress) {
                        eventProgressBar.setValue(progress);
                    }
                }
            });
        }

        if (arg instanceof ProcessPreparingEvent) {
            SwingUtilities.invokeLater(new Runnable() {

                @Override
                public void run() {
                    progressDialog.setVisible(true);
                    eventProgressBar.setIndeterminate(true);
                }
            });
        }
    }

    @Action
    public void helpQuickStart() {
        String tempfolder = System.getProperty("java.io.tmpdir");
        String quickStartFile = "/StatQuantQuickstart.pdf";
        File file = new File(tempfolder + quickStartFile);
        BufferedInputStream bin = null;
        FileOutputStream bout = null;
        try {
            if (!file.exists()) {


                bin = new BufferedInputStream(getClass().getResourceAsStream(quickStartFile));
                bout = new FileOutputStream(file);

                byte[] data = new byte[4096];
                while (true) {
                    int read;
                    read = bin.read(data);

                    if (read == -1) {
                        break;
                    }
                    bout.write(data, 0, read);
                }
            }
        } catch (FileNotFoundException ex) {
            Logger.getLogger(StatQuantGuiView.class.getName()).log(Level.SEVERE, null, ex);
        } catch (IOException ex) {
            Logger.getLogger(StatQuantGuiView.class.getName()).log(Level.SEVERE, null, ex);
        } finally {
            try {
                if (bin != null) {
                    bin.close();
                }
                if (bout != null) {
                    bout.close();
                }
            } catch (IOException ex) {
                Logger.getLogger(StatQuantGuiView.class.getName()).log(Level.SEVERE, null, ex);
            }
        }

        PDFViewer view = new com.sun.pdfview.PDFViewer(false);
        view.setAlwaysOnTop(true);
        view.setDefaultCloseOperation(PDFViewer.DISPOSE_ON_CLOSE);
        view.doOpen(file.getPath());

    }

    @Action
    public void conversionCancelAction() {
        conversionSettingsDialog.setVisible(false);
    }

    @Action
    public void correctionDialogCancelButtonAction() {
        correctionDialog.setVisible(false);
    }

    @Action
    public void saveExcelProtList() {
        saveExcel(false);
    }

    @Action
    public void saveExcelReport() {
        saveExcel(true);
    }

    public void saveExcel(boolean report) {
        JFileChooser saveReportFileDialot = new JFileChooser();

        int returnval = saveReportFileDialot.showSaveDialog(SaveReportItem);

        if (!(returnval == JFileChooser.CANCEL_OPTION)) {
            java.io.File saveFile = saveReportFileDialot.getSelectedFile();
            //jFileChooser1.
            int activeExp = TopTabPane.getSelectedIndex();
            ProtsAndPepsDataHandler dataHandler = experiments.get(activeExp);

            try {
                dataHandler.savelReportAsExcel(saveFile.getAbsolutePath(), TopTabPane.getTitleAt(TopTabPane.getSelectedIndex()), report);
            } catch (IOException ex) {
                Logger.getLogger(StatQuantGuiView.class.getName()).log(Level.SEVERE, null, ex);
            } catch (WriteException ex) {
                Logger.getLogger(StatQuantGuiView.class.getName()).log(Level.SEVERE, null, ex);
            }

        }
    }
}
