/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package nl.uu.chem.bioinformatics.statquant.parsers;

import nl.uu.chem.bioinformatics.statquant.model.QuantifiedAminoAcidSequence;
import java.io.File;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 *
 * @author Breuk102
 */
public class GenericParser {
// Generic info to be used when I want to implement a kind of plug and play thing in my program
    private String ParserName = "GenericParser"; // Parser Protein header less MSQuantOutputfiles
    private float ParserVersion = 0.1f;
    private String filename;
    private String Protein;
    private HashMap<String, String[]> ProteinInfo = new HashMap<String, String[]>();
    private QuantifiedAminoAcidSequence QAAS;
    private HashMap<String, ArrayList<QuantifiedAminoAcidSequence>> ProtsAndPeps = new HashMap<String, ArrayList<QuantifiedAminoAcidSequence>>();
    private RandomAccessFile RF;
    private File GenericFile;
    private HashMap<String, ArrayList<String>> mods = new HashMap<String, ArrayList<String>>();
    private HashMap<String, String> symbol = new HashMap<String, String>();
    private boolean headerIsRead = false;
    private boolean useUniquePeptidesOnly = false; // Is true ADD peptide areas of not unique peptides from the same protein
    private boolean usePeptideReport = false; // Is true than protein names are not hashes for ProtsAndPeps but the sequences;
    // An absolutely required setting... which column contains the protein name!
    private int proteinNameColumn = 0; //start counting from 0 for column 1
    // Other required settings are the columns for signals en peptideseq.
    private int peptideColumn = 0; //starting from 0!
    private int peptideSignalA = 0; //actually this is not used in this parser. done by datahandler
    private int peptideSignalB = 0; // idem. (only used in debuggung for now)
    private int proteinDescriptionColumn = 0;
    private int PTMpositionColNumber = 0;
    private boolean setColumns = true;
    // MSQUANT SPECIFIC?
    private int modificationColumn = 0;
    private ArrayList<String[]> headers = new ArrayList<String[]>();
    //
    public GenericParser() {
    }

    public void run() {
        try {
            GenericFile = new java.io.File(filename);
            readFile();
        } catch (IOException ex) {
            Logger.getLogger("global").log(Level.SEVERE, null, ex);
        }
        getProtsAndPeps();
    }

    public void readFile() throws IOException {
        String line;
        String protein = "";
        // this.fillMods();
        boolean Peplines = false;
        RF = new RandomAccessFile(GenericFile, "r");
        ArrayList<Object> RAFilePointers = new ArrayList<Object>();
        // RAFilePointers.add(RF.getFilePointer()); //start of doc. 1st line
        while ((line = RF.readLine()) != null) {
            // ghet rid of trailing white spaces or newlines etc
            line = line.trim();

            // we take the TAB delimited line and SPLIT it on tabs \t we now have column data as an array. array index is column number
            String[] Line_array = line.split("\t");

            // We do not want to parse a header (again), I use pattern recognition. if a header name is in a line it is not parsed
            Pattern pattern = Pattern.compile(".*Accession number.*");
            Matcher matcher = pattern.matcher(line);
            if (matcher.matches()) {
                Peplines = false;
            } else {
                Peplines = true;
            }

            // get peptide AND protein data
            // ignore empty lines and skip is peplines = false (that it is a header)
            if ((!(line.equalsIgnoreCase(""))) && Peplines) {
                // ok from here we can use the Line_array.
                // first get the two signal columns: peptideSignal A and B (or XIC)
                float _sigA = Float.parseFloat(Line_array[this.peptideSignalA]);
                float _sigB = Float.parseFloat(Line_array[this.peptideSignalB]);

                //check if they are larger than zero! if not the data is useless anyway.. we do not continue with this data and move to the next
                if (_sigA > 0f && _sigB > 0f) {
                    // create a container to store the peptide with all info in.
                    QAAS = new QuantifiedAminoAcidSequence();
                    // StatQuant offers two options, a peptide report: here per peptide all info is stored, and the uniqe ID is the peptide with its mods
                    // or normal and than the protein name is used as unique id. In the first case you expect only one peptide per peptide ID. In the second case multiple peptides belong to one protein.
                    // We need to make a unique ID for peptides which is a combo of the peptide with its mod.
                    if (!this.usePeptideReport) {
                        protein = Line_array[this.proteinNameColumn];
                    } else {
                        if (this.PTMpositionColNumber > 0) { // you need a mod if not... just the peptide name
                            String Mod = Line_array[this.modificationColumn];
                            protein = Line_array[this.peptideColumn] + Mod;
                        } else {
                            protein = Line_array[this.peptideColumn];
                        }
                    }// END peptide report settings

                    // we also maintain a list with all protein names (uniques)
                    if (!(ProteinInfo.containsKey(protein))) {
                        ProteinInfo.put(protein, Line_array);
                    }

                    // Now we are going to store all proteins with their respective peptides (and their info) into our ProtsAndPeps datablock
                    // ofcourse only if its a new protein we need to create it. else we add new peptides to it.
                    if (ProtsAndPeps.containsKey(protein)) {
                        // the useUniquePeptidesOnly setting is used to add up the signals of similar peptides (with mods) in different samples (files)
                        // this reduces the variation.
                        if (this.useUniquePeptidesOnly) {
                            boolean unique = true;
                            uniquepeptide:
                            for (int t = 0; t < ProtsAndPeps.get(protein).size(); t++) {
                                if (ProtsAndPeps.get(protein).get(t).getSequence().equals(Line_array[this.peptideColumn])) {
                                    // next make sure that it has the same modifications
                                    // when the peptide is not unique the peptide areas are added and reused to calulcate the ratio
                                    if (ProtsAndPeps.get(protein).get(t).getModification().equals(Line_array[this.modificationColumn])) {
                                        // ADD AREAS
                                        String[] pepinfo = ProtsAndPeps.get(protein).get(t).getPeptideinfo();
                                        float sigA = Float.parseFloat(Line_array[this.peptideSignalA]);
                                        float sigB = Float.parseFloat(Line_array[this.peptideSignalB]);
                                        sigA += Float.parseFloat(pepinfo[this.peptideSignalA]);
                                        sigB += Float.parseFloat(pepinfo[this.peptideSignalB]);
                                        pepinfo[this.peptideSignalA] = Float.toString(sigA);
                                        pepinfo[this.peptideSignalB] = Float.toString(sigB);
                                        ProtsAndPeps.get(protein).get(t).setPeptideinfo(pepinfo);
                                        float ratioBA = Float.parseFloat(pepinfo[this.peptideSignalB]) / Float.parseFloat(pepinfo[this.peptideSignalA]);
                                        ProtsAndPeps.get(protein).get(t).setRatio(ratioBA);
                                        unique = false;
                                        break uniquepeptide;
                                    } // and mod compare
                                } // END if sequence compare
                            }// END FOR

                            // If the peptide is unique.. add
                            if (unique) {
                                QAAS.setSequence(Line_array[this.peptideColumn]);
                                QAAS.setPeptideinfo(Line_array);
                                QAAS.setModification(Line_array[this.modificationColumn]);
                                float ratioBA = Float.parseFloat(Line_array[this.peptideSignalB]) / Float.parseFloat(Line_array[this.peptideSignalA]);
                                QAAS.setRatio(ratioBA);
                                ProtsAndPeps.get(protein).add(QAAS);
                            }// END IF UNIQUE
                        } else {
                            QAAS.setSequence(Line_array[this.peptideColumn]);
                            QAAS.setPeptideinfo(Line_array);
                            QAAS.setModification(Line_array[this.modificationColumn]);
                            float ratioBA = Float.parseFloat(Line_array[this.peptideSignalB]) / Float.parseFloat(Line_array[this.peptideSignalA]);
                            QAAS.setRatio(ratioBA);
                            ProtsAndPeps.get(protein).add(QAAS);
                        }// END USE unique Peptides Only
                    } else {
                        //new protein
                        QAAS.setSequence(Line_array[this.peptideColumn]);
                        QAAS.setPeptideinfo(Line_array);
                        QAAS.setModification(Line_array[this.modificationColumn]);
                        float ratioBA = Float.parseFloat(Line_array[this.peptideSignalB]) / Float.parseFloat(Line_array[this.peptideSignalA]);
                        QAAS.setRatio(ratioBA);
                        ArrayList<QuantifiedAminoAcidSequence> QAASlist = new ArrayList<QuantifiedAminoAcidSequence>();
                        QAASlist.add(QAAS);
                        ProtsAndPeps.put(protein, QAASlist);
                    }//end protsAndPeps
                }// END check larger than zero
            }// END PARSE PEPTIDES        
        }// END WHILE LOOP TROUGH FILE
    }// END public

    public void determineColumnsFromFirstRead() throws IOException {
        String line;
        String protein = "";
        GenericFile = new java.io.File(filename);
        boolean Peplines = false;
        RF = new RandomAccessFile(GenericFile, "r");
        search:
        while ((line = RF.readLine()) != null) {
            line = line.trim();
            String[] Line_array = line.split("\t");

            //      Pattern pattern = Pattern.compile(".*Accession number.*");
            Pattern pattern = Pattern.compile(".*Accession number.*");
            Matcher matcher = pattern.matcher(line);
            if (matcher.matches()) {
                this.headers.add(0, line.split("\t"));
                this.headers.add(1, line.split("\t"));
                // System.out.println(hline);
                break search;
            }
        }
        // we have the header.. lets determine the actual header columns
        this.peptideColumn = this.headerIndex("Sequence");
        this.modificationColumn = this.headerIndex("Modifications");
        this.peptideSignalA = this.headerIndex("Intensity 1");
        this.peptideSignalB = this.headerIndex("Intensity 2");
        this.proteinNameColumn = this.headerIndex("Accession number");
        this.proteinDescriptionColumn = this.headerIndex("Description");
    }

    /**
     * 
     * @param headerName = name of the column header to find the index of
     * @return This function returns the index number (int) of the column that contains the searched header.
     */
    public int headerIndex(String headerName) {
        String[] index = this.headers.get(1);
        int found = 0;
        for (int t = 0; t < index.length; t++) {
            if (index[t].equals(headerName)) {
                found = t;
            }
        }
        //System.out.println(headerName +" "+ String.valueOf(found));
        return found;
    }
    // GETTERS AND SETTERS
    public int getModificationColumn() {
        return modificationColumn;
    }

    public void setModificationColumn(int modificationColumn) {
        this.modificationColumn = modificationColumn;
    }

    public boolean isUsePeptideReport() {
        return usePeptideReport;
    }

    public void setUsePeptideReport(boolean usePeptideReport) {
        this.usePeptideReport = usePeptideReport;
    }

    public int getPTMpositionColNumber() {
        return PTMpositionColNumber;
    }

    public void setPTMpositionColNumber(int PTMpositionColNumber) {
        this.PTMpositionColNumber = PTMpositionColNumber;
    }

    public int getProteinDescriptionColumn() {
        return proteinDescriptionColumn;
    }

    public void setProteinDescriptionColumn(int proteinDescriptionColumn) {
        this.proteinDescriptionColumn = proteinDescriptionColumn;
    }

    public void setProteinInfo(HashMap<String, String[]> ProteinInfo) {
        this.ProteinInfo = ProteinInfo;
    }

    public HashMap<String, String[]> getProteinInfo() {
        return ProteinInfo;
    }

    public void setPeptideColumn(int peptideColumn) {
        this.peptideColumn = peptideColumn;
    }

    public void setPeptideSignalA(int peptideSignalA) {
        this.peptideSignalA = peptideSignalA;
    }

    public void setPeptideSignalB(int peptideSignalB) {
        this.peptideSignalB = peptideSignalB;
    }

    public void setProteinNameColumn(int c) {
        this.proteinNameColumn = c;
    }

    public int getPeptideColumn() {
        return peptideColumn;
    }

    public int getPeptideSignalA() {
        return peptideSignalA;
    }

    public int getPeptideSignalB() {
        return peptideSignalB;
    }

    public int getProteinNameColumn() {
        return proteinNameColumn;
    }

    public void setFileName(String fn) {
        this.filename = fn;
    }

    public String getParserName() {
        return ParserName;
    }

    public float getParserVersion() {
        return ParserVersion;
    }

    public void setProtsAndPeps(HashMap<String, ArrayList<QuantifiedAminoAcidSequence>> ProtsAndPeps) {
        this.ProtsAndPeps = ProtsAndPeps;
    }

    public HashMap getProtsAndPeps() {

        return ProtsAndPeps;
    }

    // This getHeaders functions returns all headers found as defined in the parser. A generic parser would return more or less headers.
    public ArrayList<String[]> getHeaders() {

        return headers;
    }

    public boolean isUseUniquePeptidesOnly() {
        return useUniquePeptidesOnly;
    }

    public void setUseUniquePeptidesOnly(boolean useUniquePeptidesOnly) {
        this.useUniquePeptidesOnly = useUniquePeptidesOnly;
    }
}
